@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file Child.cpp
  */
 
-#include <config.h>
-
 #include "Child.hpp"
 #include "Component.hpp"
 
@@ -85,3 +83,6 @@ Childs::clear()
     std::vector<Child>::clear();
 }
 
+
+/** @file gui/Child.cpp */
+
