@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @author Matthias Braun
  */
 
-#include <config.h>
-
 #include <typeinfo>
 #include <stdexcept>
 #include "Component.hpp"
@@ -77,10 +75,8 @@ Component::draw(Painter& painter)
 {
     for(Childs::iterator i = childs.begin(); i != childs.end(); ++i) {
         Child& child = *i;
-        if(!child.enabled)
-            continue;
-
-        drawChild(child, painter);
+        if(child.enabled)
+            drawChild(child, painter);
     }
 }
 
@@ -90,9 +86,10 @@ Component::eventChild(Child& child, const Event& event, bool visible)
     assert(child.getComponent() != 0);
 
     Event ev = event;
-    if(event.type == Event::MOUSEMOTION 
+    if(event.type == Event::MOUSEMOTION
         || event.type == Event::MOUSEBUTTONDOWN
-        || event.type == Event::MOUSEBUTTONUP) {
+        || event.type == Event::MOUSEBUTTONUP
+        || event.type == Event::MOUSEWHEEL) {
         ev.mousepos -= child.position;
         if(visible && child.component->opaque(ev.mousepos))
             ev.inside = true;
@@ -134,12 +131,11 @@ Component::findComponent(const std::string& name)
 
     for(Childs::const_iterator i = childs.begin(); i != childs.end(); ++i) {
         const Child& child = *i;
-        if(!child.getComponent())
-            continue;
-
-        Component* component = child.component->findComponent(name);
-        if(component)
-            return component;
+        if (child.getComponent()) {
+            Component* component = child.component->findComponent(name);
+            if(component)
+                return component;
+        }
     }
 
     return 0;
@@ -210,7 +206,8 @@ Component::setChildDirty(Component* childComponent, const Rect2D& area)
         const Child& child = *i;
         if(child.getComponent() != childComponent)
             continue;
-
+        if(!child.enabled)
+            return;
         Rect2D rect = area;
         rect.move(child.position);
         setDirty(rect);
@@ -220,3 +217,5 @@ Component::setChildDirty(Component* childComponent, const Rect2D& area)
     assert(false);
 }
 
+
+/** @file gui/Component.cpp */
