@@ -21,35 +21,46 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file ComponentLoader.cpp
  */
 
-#include <config.h>
-
 #include "ComponentLoader.hpp"
 #include "ComponentFactory.hpp"
 #include "XmlReader.hpp"
 #include "Desktop.hpp"
 #include "Style.hpp"
 
+
 #include <sstream>
 #include <stdexcept>
 #include <iostream>
 #include <memory>
 
-void initFactories();
+//void initFactories();
 
 Component* createComponent(const std::string& type, XmlReader& reader)
 {
-    initFactories();
-    
+    //static int depth = 0;
+    //initFactories();
+    //Component * component = 0;
     if(component_factories == 0)
         throw std::runtime_error("No component factories registered");
-    
+
     ComponentFactories::iterator i = component_factories->find(type);
     if(i == component_factories->end()) {
         std::stringstream msg;
         msg << "Couldn't find a component factory for '" << type << "'";
         throw std::runtime_error(msg.str());
     }
-   
+/*
+    for(int i=0;i<depth;++i)
+        std::cout << "\t";
+    std::cout << type << ": begin" <<std::endl;
+    std::cout.flush();
+    ++depth;
+    component = i->second->createComponent(reader);
+    --depth;
+    for(int i=0;i<depth;++i)
+        std::cout << "\t";
+    std::cout << type << ": end" << std::endl;
+*/
     try {
         return i->second->createComponent(reader);
     } catch(std::exception& e) {
@@ -64,15 +75,15 @@ Component* createComponent(const std::string& type, XmlReader& reader)
 Component* loadGUIFile(const std::string& filename)
 {
     XmlReader reader(filename);
-   
+
     std::string componentName = (const char*) reader.getName();
     if(componentName == "gui") {
-        std::auto_ptr<Desktop> desktop (new Desktop());
+        std::unique_ptr<Desktop> desktop (new Desktop());
         desktop->parse(reader);
         return desktop.release();
     }
-    
-    std::auto_ptr<Component> component (createComponent(componentName, reader));
+
+    std::unique_ptr<Component> component (createComponent(componentName, reader));
     return component.release();
 }
 
@@ -103,3 +114,6 @@ Component* parseEmbeddedComponent(XmlReader& reader)
     return component;
 }
 
+
+/** @file gui/ComponentLoader.cpp */
+
