@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file Desktop.cpp
  */
 
-#include <config.h>
-
 #include "Desktop.hpp"
 
 #include <iostream>
@@ -243,3 +241,6 @@ Desktop::addChildComponent(Component* component)
     assert( component->getParent() == 0 );
     addQueue.push_back(component);
 }
+
+/** @file gui/Desktop.cpp */
+
