@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file Document.cpp
  */
 
-#include <config.h>
-
 #include "Document.hpp"
 
 #include <iostream>
@@ -71,7 +69,7 @@ Document::parse(XmlReader& reader)
         if(reader.getNodeType() == XML_READER_TYPE_ELEMENT) {
             std::string node = (const char*) reader.getName();
             if(node == "p" || node=="Paragraph" || node == "li") {
-                std::auto_ptr<Paragraph> paragraph (new Paragraph());
+                std::unique_ptr<Paragraph> paragraph (new Paragraph());
                 if(node != "li") {
                     paragraph->parse(reader, style);
                 } else {
@@ -81,7 +79,7 @@ Document::parse(XmlReader& reader)
                     makeCallback(*this, &Document::paragraphLinkClicked));
                 addChild(paragraph.release());
             } else if(node == "img") {
-                std::auto_ptr<DocumentImage> image (new DocumentImage());
+                std::unique_ptr<DocumentImage> image (new DocumentImage());
                 image->parse(reader, style);
                 addChild(image.release());
             } else {
@@ -165,4 +163,7 @@ Document::paragraphLinkClicked(Paragraph* paragraph, const std::string& href)
     linkClicked(paragraph, href);
 }
 
-IMPLEMENT_COMPONENT_FACTORY(Document);
+IMPLEMENT_COMPONENT_FACTORY(Document)
+
+/** @file gui/Document.cpp */
+
