@@ -21,9 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file FilledRectangle.cpp
  */
 
-#include <config.h>
-
-#include <assert.h>
 #include <iostream>
 
 #include "FilledRectangle.hpp"
@@ -73,3 +70,6 @@ FilledRectangle::draw(Painter& painter)
 }
 
 IMPLEMENT_COMPONENT_FACTORY(FilledRectangle)
+
+/** @file gui/FilledRectangle.cpp */
+
