@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file Image.cpp
  */
 
-#include <config.h>
-
 #include "Image.hpp"
 #include "XmlReader.hpp"
 #include "TextureManager.hpp"
@@ -134,5 +132,8 @@ void Image::setFile(const std::string &pfilename)
     texture = texture_manager->load(pfilename);
 }
 
-IMPLEMENT_COMPONENT_FACTORY(Image);
+IMPLEMENT_COMPONENT_FACTORY(Image)
+
+
+/** @file gui/Image.cpp */
 
