@@ -15,8 +15,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <config.h>
-
 #include "TextureGL.hpp"
 
 #include <SDL_opengl.h>
@@ -32,3 +30,6 @@ TextureGL::~TextureGL()
     glDeleteTextures(1, handles);
 }
 
+
+/** @file gui/PainterGL/TextureGL.cpp */
+
