@@ -15,8 +15,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <config.h>
-
 #include "TextureManagerGL.hpp"
 
 #include <SDL_opengl.h>
@@ -62,8 +60,8 @@ TextureManagerGL::create(SDL_Surface* image)
             << " (out of memory?): " << SDL_GetError();
         throw std::runtime_error(msg.str());
     }
-    SDL_SetAlpha(image, 0, 0);
-    SDL_BlitSurface(image, 0, convert, 0);
+    SDL_SetSurfaceAlphaMod(image, 255);
+    SDL_BlitSurface(image, NULL, convert, NULL);
 
     GLuint handle;
     glGenTextures(1, &handle);
@@ -72,15 +70,18 @@ TextureManagerGL::create(SDL_Surface* image)
 
     glBindTexture(GL_TEXTURE_2D, handle);
     glPixelStorei(GL_UNPACK_ROW_LENGTH, convert->pitch/format->BytesPerPixel);
+	glTexParameteri(GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_TRUE);
     glTexImage2D(GL_TEXTURE_2D, 0, format->BytesPerPixel,
             convert->w, convert->h, 0, GL_RGBA,
             GL_UNSIGNED_BYTE, convert->pixels);
 
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_R, GL_CLAMP);
+	GLfloat yellow[4] = { 1.0f, 1.0f, 0.0f, 1.0f };
+    glTexParameterfv(GL_TEXTURE_2D, GL_TEXTURE_BORDER_COLOR, yellow);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_R, GL_REPEAT);
 
     TextureGL* texture = new TextureGL(handle);
     texture->rect = Rect2D(0, 0,
@@ -94,3 +95,6 @@ TextureManagerGL::create(SDL_Surface* image)
     return texture;
 }
 
+
+/** @file gui/PainterGL/TextureManagerGL.cpp */
+
