@@ -15,8 +15,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <config.h>
-
 #include "TextureSDL.hpp"
 
 TextureSDL::~TextureSDL()
@@ -29,3 +27,6 @@ TextureSDL::~TextureSDL()
         zoomSurface = NULL;
     }
 }
+
+/** @file gui/PainterSDL/TextureSDL.cpp */
+
