@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file Panel.cpp
  */
 
-#include <config.h>
-
 #include "Panel.hpp"
 
 #include <sstream>
@@ -132,5 +130,8 @@ Panel::opaque(const Vector2& pos) const
     return false;
 }
 
-IMPLEMENT_COMPONENT_FACTORY(Panel);
+IMPLEMENT_COMPONENT_FACTORY(Panel)
+
+
+/** @file gui/Panel.cpp */
 
