@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file Paragraph.cpp
  */
 
-#include <config.h>
-
 #include "Paragraph.hpp"
 
 #include <iostream>
@@ -40,7 +38,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "XmlReader.hpp"
 #include "ComponentFactory.hpp"
 #include "Document.hpp"
-#include "tinygettext/TinyGetText.hpp"
+#include "tinygettext/tinygettext.hpp"
 
 Paragraph::Paragraph()
     : texture(0)
@@ -65,7 +63,7 @@ void
 Paragraph::parseList(XmlReader& reader, const Style& )
 {
     // query for "list" style
-    std::map<std::string, Style>::iterator i 
+    std::map<std::string, Style>::iterator i
         = styleRegistry.find("list");
     if(i == styleRegistry.end()) {
         throw std::runtime_error("<li> element used but no"
@@ -81,12 +79,27 @@ Paragraph::parseList(XmlReader& reader, const Style& )
     parse(reader, i->second);
 }
 
+void
+Paragraph::commit_changes(TextSpan* &currentspan, bool translatable)
+{
+  if (currentspan != 0) {
+    if (translatable) {
+      currentspan->text
+        = GUI_TRANSLATE(currentspan->text);
+    }
+    textspans.push_back(currentspan);
+    //std::cout << "new span: " << currentspan->text << std::endl;
+    currentspan = 0;
+  }
+}
+
 void
 Paragraph::parse(XmlReader& reader, const Style& parentstyle)
 {
     bool translatable = false;
-    
+
     style = parentstyle;
+
     XmlReader::AttributeIterator iter(reader);
     while(iter.next()) {
         const char* attribute = (const char*) iter.getName();
@@ -105,105 +118,106 @@ Paragraph::parse(XmlReader& reader, const Style& parentstyle)
 
     std::vector<Style> stylestack;
     stylestack.push_back(style);
+    stylestack.back().toSpan();
 
     TextSpan* currentspan = 0;
-  
+
     try {
         std::string currenthref;
         int depth = reader.getDepth();
         while(reader.read() && reader.getDepth() > depth) {
-            if(reader.getNodeType() == XML_READER_TYPE_ELEMENT) {
-                std::string node((const char*) reader.getName());
-                if(node == "span" || node == "i" || node == "b"
-                        || node == "a") {
-                    if(currentspan != 0) {
-                        if(translatable) {
-                            currentspan->text 
-                                = GUI_TRANSLATE(currentspan->text);
-                        }
-                        textspans.push_back(currentspan);
-                        currentspan = 0;
-                    }
-                    
-                    Style style(stylestack.back());
-                    if (node == "a") {
-                        style.text_color.parse("blue");
-                    } else if(node == "i") {
-                        style.italic = true;
-                    } else if(node == "b") {
-                        style.bold = true;
-                    }
-                    
-                    currenthref = "";
-                    XmlReader::AttributeIterator iter(reader);
-                    while(iter.next()) {
-                        const char* attribute = (const char*) iter.getName();
-                        const char* value = (const char*) iter.getValue();
-                        if(style.parseAttribute(attribute, value))
-                            continue;
-                        else if(strcmp(attribute, "href") == 0) {
-                            currenthref = value;
-                        } else {
-                            std::cerr << "Unknown attribute '" << attribute
-                                << "' in textspan node.\n";
-                        }
-                    }
-                    style.parseAttributes(reader);
-                    // TODO parse style attributes...
-                    stylestack.push_back(style);       
-                } else {
-                    std::cerr << "Skipping unknown node '" << node << "'.\n";
-                    reader.nextNode();
+          switch(reader.getNodeType()) {
+            case XML_READER_TYPE_ELEMENT:
+            {
+              std::string node((const char*) reader.getName());
+              if(node == "span" || node == "i" || node == "b"
+                  || node == "a") {
+                commit_changes(currentspan,translatable);
+
+                Style style(stylestack.back());
+                if (node == "a") {
+                  style.text_color.parse("blue");
+                } else if(node == "i") {
+                  style.italic = true;
+                } else if(node == "b") {
+                  style.bold = true;
                 }
-            } else if(reader.getNodeType() == XML_READER_TYPE_TEXT) {
-                if(currentspan == 0) {
-                    currentspan = new TextSpan();
-                    currentspan->style = stylestack.back();
-                }
-                
-                const char* p = (const char*) reader.getValue();
-                // skip trailing spaces...
-                while(*p != 0 && isspace(static_cast<unsigned char>(*p)))
-                    ++p;
-            
-                bool lastspace = false;
-                for( ; *p != 0; ++p) {
-                    if(isspace(static_cast<unsigned char>(*p))) {
-                        if(!lastspace) {
-                            lastspace = true;
-                            currentspan->text += ' ';
-                        }
-                    } else {
-                        lastspace = false;
-                        currentspan->text += *p;
-                    }
-                }
-            } else if(reader.getNodeType() == XML_READER_TYPE_END_ELEMENT) {
-                std::string node((const char*) reader.getName());
-                if(node == "span" || node == "b" || node == "i"
-                        || node == "a") {
-                    if(currentspan != 0) {
-                        if(translatable) {
-                            currentspan->text 
-                                = GUI_TRANSLATE(currentspan->text);
-                        }
-                        textspans.push_back(currentspan);
-                        currentspan = 0;
-                    }                                                              
-                    stylestack.pop_back();
-                } else {
-                    std::cerr << "Internal error: unknown node end: '" <<
-                        node << "'.\n";
+
+                currenthref = "";
+                XmlReader::AttributeIterator iter(reader);
+                while(iter.next()) {
+                  const char* attribute = (const char*) iter.getName();
+                  const char* value = (const char*) iter.getValue();
+                  if(style.parseAttribute(attribute, value))
+                    continue;
+                  else if(strcmp(attribute, "href") == 0) {
+                    currenthref = value;
+                  } else {
+                    std::cerr << "Unknown attribute '" << attribute
+                      << "' in textspan node.\n";
+                  }
                 }
+                style.parseAttributes(reader);
+                // TODO parse style attributes...
+                stylestack.push_back(style);
+              } else {
+                std::cerr << "Skipping unknown node '" << node << "'.\n";
+                reader.nextNode();
+              }
             }
+            break;
+            case XML_READER_TYPE_TEXT:
+            {
+              if(currentspan == 0) {
+                currentspan = new TextSpan();
+                currentspan->style = stylestack.back();
+              }
+
+              const char* p = (const char*) reader.getValue();
+              // skip trailing spaces...
+              while(*p != 0 && isspace(static_cast<unsigned char>(*p)))
+                ++p;
+
+              bool lastspace = false;
+              for( ; *p != 0; ++p) {
+                if(isspace(static_cast<unsigned char>(*p))) {
+                  if(!lastspace) {
+                    lastspace = true;
+                    currentspan->text += ' ';
+                  }
+                } else {
+                  lastspace = false;
+                  currentspan->text += *p;
+                  //std::cout << "growing span: " << currentspan->text << std::endl;
+                }
+              }
+
+            }
+            break;
+            case XML_READER_TYPE_END_ELEMENT:
+            {
+              std::string node((const char*) reader.getName());
+              if(node == "span" || node == "b" || node == "i"
+                  || node == "a") {
+                commit_changes(currentspan,translatable);
+                stylestack.pop_back();
+              } else {
+                std::cerr << "Internal error: unknown node end: '" <<
+                  node << "'.\n";
+              }
+            }
+            break;
+          }
         }
 
         if(currentspan != 0) {
             if(translatable) {
-                currentspan->text 
+                currentspan->text
                     = GUI_TRANSLATE(currentspan->text);
             }
+            //std::cout << "completed span: " << currentspan->text << std::endl;
             textspans.push_back(currentspan);
+            currentspan = 0; //added CK
         }
     } catch(...) {
         if(currentspan != 0)
@@ -213,7 +227,7 @@ Paragraph::parse(XmlReader& reader, const Style& parentstyle)
 }
 
 /**
- * Reflows the text and renders it onto a texture 
+ * Reflows the text and renders it onto a texture
  * Cleaning this big code up a bit more is always nice. However be very careful
  * when doing so and test it alot, as the code very easily breaks...
  */
@@ -221,13 +235,17 @@ void
 Paragraph::resize(float width, float height)
 {
     // free old texture
-    if(texture) {
+    if(texture)
+    {
         delete texture;
         texture = 0;
     }
 
-    if(width == 0) {
-        this->width = this->height = 0;
+    if( (width == 0) || textspans.empty() )
+    {
+        this->width = 0;
+        this->height = 0;
+        texture = 0;
         return;
     }
 
@@ -237,19 +255,13 @@ Paragraph::resize(float width, float height)
     std::vector<SDL_Surface*> lineimages;
     // surfaces for the current line
     std::vector<SDL_Surface*> spanimages;
+    std::vector<float> spanxoffset;
     std::vector<LinkRectangle> linerectangles;
     std::vector<int> spanbaselines;
     int lineheight = 0;
     int baseline = 0;
 
-    if(textspans.empty()) {
-        // no need to render anything if there are no spans
-        this->width = 0;
-        this->height = 0;
-        texture = 0;
-        return;
-    }
-    
+
     TextSpans::iterator i = textspans.begin();
 
     const TextSpan* span = *i;
@@ -262,24 +274,25 @@ Paragraph::resize(float width, float height)
     std::string line;
     // current rendering position
     Vector2 pos;
-
     while(1) {
         std::string::size_type lastp = p;
-        if( (*text) [p] == ' ') {
+        if( (*text) [p] == ' ')
+        {
             // we don't need the space at the beginning of the line
             if(p-linestart != 0 || pos.x != 0)
-                line += ' ';
-            else {
+            {   line += ' ';}
+            else
+            {
                 lastp++;
                 linestart++;
             }
             ++p;
         }
-            
+
         // take a word
-        for( ; p < text->size() && (*text) [p] != ' '; ++p) {
-            line += (*text) [p]; 
-        }
+        for( ; p < text->size() &&
+            !( ((*text) [p] == ' ') /*|| ((*text) [p] == '\t')*/ ); ++p)
+        {   line += (*text) [p];}
 
         // check line size...
         int render_width, render_height;
@@ -288,10 +301,10 @@ Paragraph::resize(float width, float height)
         bool render = false;
         bool linefeed = false;
         // we need a linefeed if width isn't enough for current span
-        if(width > 0 && pos.x + render_width >= width) {
+        if(width > 0 && pos.x + render_width >= width - style.margin_left - style.margin_right)
+        {
             render = true;
             linefeed = true;
-           
             // we have to leave out the last word (which made it too width)
             if(lastp-linestart > 0 || pos.x != 0) {
                 line = std::string(*text, linestart, lastp-linestart);
@@ -304,19 +317,22 @@ Paragraph::resize(float width, float height)
         /* span is over, so we need to render now (and if it was the last span,
          * we need a linefeed too)
          */
-        if(p >= text->size()) {
+        if(p >= text->size())
+        {
             render = true;
             ++i;
             if(i == textspans.end())
-                linefeed = true;
+            {   linefeed = true;}
         }
-        
-        if(render && line != "") {
-            if(TTF_FontHeight(font) > lineheight) {
+
+        if(render && line != "")
+        {
+            if(TTF_FontHeight(font) > lineheight)
+            {
                 lineheight = TTF_FontHeight(font);
                 baseline = TTF_FontAscent(font);
             }
-            
+
             // render span
             //printf("Rendering: '%s'.\n", line.c_str());
             SDL_Surface* spansurface = TTF_RenderUTF8_Blended(font,
@@ -326,20 +342,49 @@ Paragraph::resize(float width, float height)
                 msg << "Error rendering text: " << SDL_GetError();
                 throw std::runtime_error(msg.str());
             }
-            SDL_SetAlpha(spansurface, 0, 0);
+            SDL_SetSurfaceAlphaMod(spansurface, 255);
+            //remember individual margins of spans
+            float xoffset;
+            bool new_column = false;
+            if(span->style.alignment == Style::ALIGN_LEFT)
+            {
+                xoffset = span->style.margin_left;
+                new_column = (xoffset!=0);
+            }
+            else if(span->style.alignment == Style::ALIGN_CENTER)
+            {
+                new_column = (span->style.margin_left!=0);
+                if (new_column)
+                {   xoffset = (width + span->style.margin_left - span->style.margin_right - spansurface->w)/2;}
+                else
+                {   xoffset = 0;}
+            }
+            else
+            {
+                new_column = true; //always new column for right adjustment
+                xoffset = (width - spansurface->w - span->style.margin_right);
+            }
+            float yoffset = span->style.margin_top;
+            if (new_column)
+            {   pos.x = xoffset;}//fixed columns
+            else
+            {   pos.x += xoffset;}
+            pos.y += yoffset;
+            spanxoffset.push_back(pos.x);
             spanimages.push_back(spansurface);
             spanbaselines.push_back(TTF_FontAscent(font));
 
             // remember span position if it is a link
             if(span->style.href != "") {
                 LinkRectangle link;
-                link.rect = Rect2D (pos.x, pos.y,
+                link.rect = Rect2D (pos.x , pos.y,
                                     pos.x + spansurface->w,
                                     pos.y + spansurface->h);
                 link.span = span;
                 linerectangles.push_back(link);
             }
-            
+
+
             pos.x += spansurface->w;
             line = "";
         }
@@ -357,47 +402,44 @@ Paragraph::resize(float width, float height)
                     throw std::runtime_error(
                             "Out of memory when composing line image");
                 }
-                SDL_SetAlpha(lineimage, 0, 0);
+                SDL_SetSurfaceAlphaMod(lineimage, 255);
 
-                Sint16 x = 0;
-                SDL_Rect rect;                
+                SDL_Rect rect;
                 for(size_t i = 0; i < spanimages.size(); ++i) {
-                    rect.x = x;
-                    rect.y = baseline - spanbaselines[i];
-                    if(rect.y < 0) {
-                        rect.y = 0;
-                    }
+                    rect.x = (Sint16) spanxoffset[i];
+                    rect.y = baseline - spanbaselines[i] + textspans[i]->style.margin_top;
+                    if(rect.y < 0)
+                    {   rect.y = 0;}
 
                     SDL_BlitSurface(spanimages[i], 0, lineimage, &rect);
-                    x += spanimages[i]->w;
-
                     SDL_FreeSurface(spanimages[i]);
                 }
                 lineimages.push_back(lineimage);
             }
             spanbaselines.clear();
             spanimages.clear();
+            spanxoffset.clear();
 
             // adjust link rectangles for alignment and add them to the list
             float xoffset;
             if(style.alignment == Style::ALIGN_LEFT) {
-                xoffset = 0;
+                xoffset = style.margin_left;
             } else if(style.alignment == Style::ALIGN_CENTER) {
-                xoffset = (width - lineimages.back()->w) / 2;
+                xoffset = (width + style.margin_left - style.margin_right - lineimages.back()->w)/2;
             } else {
-                xoffset = (width - lineimages.back()->w);
+                xoffset = (width - lineimages.back()->w  - style.margin_right);
             }
             for(std::vector<LinkRectangle>::iterator i =linerectangles.begin();
                 i != linerectangles.end(); ++i) {
-                i->rect.move(Vector2(xoffset, 0));
+                i->rect.move(Vector2(xoffset, style.margin_top));
                 linkrectangles.push_back(*i);
             }
             linerectangles.clear();
 
             line = "";
             pos.x = 0;
-                            
-            ycoords.push_back(static_cast<int> (pos.y));
+
+            ycoords.push_back(static_cast<int> (pos.y + style.margin_top));
             pos.y += lineheight;
 
             lineheight = TTF_FontHeight(font);
@@ -405,9 +447,10 @@ Paragraph::resize(float width, float height)
         }
 
         // advance to next span if necessary
-        if(p >= text->size()) {
+        if(p >= text->size())
+        {
             if(i == textspans.end())
-                break;
+            {   break;}
             span = *i;
             text = &(span->text);
             font = fontManager->getFont(span->style);
@@ -416,11 +459,9 @@ Paragraph::resize(float width, float height)
         }
     }
 
-    if(height < style.min_height) {
-        height = style.min_height;	
-    } else {
-        height = pos.y;
-    }
+    height = pos.y + style.margin_top + style.margin_bottom;
+    if(height < style.min_height)
+    {   height = style.min_height;}
 
     // check height defined in style
     if(height == 0) {
@@ -440,27 +481,27 @@ Paragraph::resize(float width, float height)
     if(result == 0) {
         throw std::runtime_error("Out of memory when creating text image");
     }
+    //apply margins of paragraph
     for(size_t i = 0; i < lineimages.size(); ++i) {
         SDL_Rect rect;
+
         if(style.alignment == Style::ALIGN_LEFT) {
-            rect.x = (Sint16) 0;
+            rect.x = (Sint16) style.margin_left;
         } else if(style.alignment == Style::ALIGN_CENTER) {
-            rect.x = (Sint16) (width - lineimages[i]->w) / 2;
+            rect.x = (Sint16) (width + style.margin_left - style.margin_right - lineimages[i]->w) / 2;
         } else {
-            rect.x = (Sint16) (width - lineimages[i]->w);
+            rect.x = (Sint16) (width - lineimages[i]->w - style.margin_right);
         }
         rect.y = (Sint16) ycoords[i];
         SDL_BlitSurface(lineimages[i], 0, result, &rect);
         SDL_FreeSurface(lineimages[i]);
     }
-    SDL_Surface* surface = SDL_DisplayFormatAlpha(result);
+    SDL_Surface* surface = SDL_ConvertSurfaceFormat(result, SDL_PIXELFORMAT_RGBA8888, 0);
     SDL_FreeSurface(result);
-    if(surface == 0) {
-        throw std::runtime_error("Out of memory when creating text image(d)");
-    }
-    
-    texture = texture_manager->create(surface);
+    if(surface == NULL)
+    {   throw std::runtime_error("Out of memory when creating text image(d)");}
 
+    texture = texture_manager->create(surface);
     this->width = width;
     this->height = height;
 
@@ -471,8 +512,7 @@ void
 Paragraph::draw(Painter& painter)
 {
     if(!texture)
-        return;
-
+    {   return;}
     painter.drawTexture(texture, Vector2(0, 0));
 }
 
@@ -489,9 +529,7 @@ Paragraph::event(const Event& event)
         if(i->rect.inside(event.mousepos)) {
             if(event.type == Event::MOUSEMOTION) {
                 // TODO change mouse cursor
-            } else if(event.type == Event::MOUSEBUTTONDOWN
-                    && event.mousebutton != SDL_BUTTON_WHEELUP
-                    && event.mousebutton != SDL_BUTTON_WHEELDOWN) {
+            } else if(event.type == Event::MOUSEBUTTONDOWN) {
                 linkClicked(this, i->span->style.href);
             }
         }
@@ -501,7 +539,9 @@ Paragraph::event(const Event& event)
 void
 Paragraph::setText(const std::string& newtext)
 {
-    setText(newtext, style);
+    Style spanStyle = style;
+    spanStyle.toSpan();
+    setText(newtext, spanStyle);
 }
 
 std::string Paragraph::getText() const
@@ -515,23 +555,67 @@ std::string Paragraph::getText() const
 void
 Paragraph::setText(const std::string& newtext, const Style& style)
 {
+/*
     for(TextSpans::iterator i = textspans.begin(); i != textspans.end(); ++i)
         delete *i;
+*/
     textspans.clear();
-		if(newtext != "") {
-			TextSpan* span = new TextSpan();
-			span->style = style;
-			span->text = newtext;
-			textspans.push_back(span);
-		}
 
+    size_t span_end = newtext.find_first_of('\t',0);
+    if(span_end != newtext.npos) // we have a tab
+    {
+        int tabcount = 0;
+        std::string mytext = newtext;
+        std::string spantext;
+        while(mytext.size())
+        {
+            spantext = mytext.substr(0,span_end);//skip the first tab
+            mytext.erase(0,span_end);//drop first span
+            mytext.erase(0,1);//kill the first tab
+            span_end = mytext.find_first_of('\t',0); // next tab
+            TextSpan* span = new TextSpan();
+            span->style = style;
+            span->style.toSpan();
+            span->text = spantext;
+            textspans.push_back(span);
+            ++tabcount;
+        }
+        if (tabcount == 2)
+        {
+            textspans[0]->style.alignment = Style::ALIGN_LEFT;
+            textspans[1]->style.alignment = Style::ALIGN_RIGHT;
+        }
+        else if (tabcount == 3)
+        {
+            textspans[0]->style.alignment = Style::ALIGN_LEFT;
+            textspans[1]->style.alignment = Style::ALIGN_RIGHT;
+            textspans[1]->style.margin_right = 65;
+            textspans[2]->style.alignment = Style::ALIGN_RIGHT;
+        }
+    }
+    else // simple string to parse
+    {
+        TextSpan* span = new TextSpan();
+        span->style = style;
+        span->style.toSpan();
+        span->text = newtext;
+        textspans.push_back(span);
+    }
+
+    float oldWidth = width;
+    float oldHeight = height;
     // rerender text
     resize(width, height);
-
     // eventually trigger resize/relayout of parent component
-    if(getParent())
-        getParent()->reLayout();
+    if(width == 0 || width != oldWidth || height == 0 || height != oldHeight)
+    {
+        if(getParent())
+        {   getParent()->reLayout();}
+    }
 }
 
-IMPLEMENT_COMPONENT_FACTORY(Paragraph);
+IMPLEMENT_COMPONENT_FACTORY(Paragraph)
+
+
+/** @file gui/Paragraph.cpp */
 
