@@ -15,8 +15,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <config.h>
-
 #include "Rect2D.hpp"
 
 #include <algorithm>
@@ -29,3 +27,6 @@ Rect2D::join(const Rect2D& other)
     p2.x = std::max(p2.x, other.p2.x);
     p2.y = std::max(p2.y, other.p2.y);
 }
+
+/** @file gui/Rect2D.cpp */
+
