@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file ScrollBar.cpp
  */
 
-#include <config.h>
-
 #include "ScrollBar.hpp"
 
 #include <sstream>
@@ -81,15 +79,15 @@ ScrollBar::parse(XmlReader& reader)
         if(reader.getNodeType() == XML_READER_TYPE_ELEMENT) {
             std::string element = (const char*) reader.getName();
             if(element == "button1") {
-                std::auto_ptr<Button> button(new Button());
+                std::unique_ptr<Button> button(new Button());
                 button->parse(reader);
                 resetChild(button1(), button.release());
             } else if(element == "button2") {
-                std::auto_ptr<Button> button(new Button());
+                std::unique_ptr<Button> button(new Button());
                 button->parse(reader);
                 resetChild(button2(), button.release());
             } else if(element == "scroller") {
-                std::auto_ptr<Button> button(new Button());
+                std::unique_ptr<Button> button(new Button());
                 button->parse(reader);                                     
                 resetChild(scroller(), button.release());                   
             } else {
@@ -218,14 +216,20 @@ ScrollBar::setRange(float min, float max)
     }
     minVal = min;
     maxVal = max;
-    currentVal = 0;
+    
+    if(currentVal < minVal)
+        currentVal = minVal;
+    else if(currentVal > maxVal)
+        currentVal = maxVal;
 }
 
 void
 ScrollBar::setValue(float value)
 {
-    if(value < minVal && value > maxVal)
-        return;
+    if(value < minVal)
+        value = minVal;
+    else if(value > maxVal)
+        value = maxVal;
     
     float scrollScreenRange = height 
         - button1().getComponent()->getHeight()
@@ -257,4 +261,6 @@ ScrollBar::buttonReleased(Button* )
     scrollspeed = 0;
 }
 
-IMPLEMENT_COMPONENT_FACTORY(ScrollBar);
+IMPLEMENT_COMPONENT_FACTORY(ScrollBar)
+
+/** @file gui/ScrollBar.cpp */
