@@ -21,8 +21,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @file Style.cpp
  */
 
-#include <config.h>
-
 #include "Style.hpp"
 #include "XmlReader.hpp"
 
@@ -123,7 +121,7 @@ Style::parseAttribute(const char* attribute, const char* value)
         if(sscanf(value, "%f", &min_width) != 1) {
             std::cerr << "Couldn't parse value for min-width: '"
                 << value << "'\n";
-        }                                                               
+        }
     } else if(strcmp(attribute, "min-height") == 0) {
         if(sscanf(value, "%f", &min_height) != 1) {
             std::cerr << "Couldn't parse value for min-height: '"
@@ -184,11 +182,25 @@ void parseStyleDef(XmlReader& reader)
                 << "' in style definition.\n";
         }
     }
-    
+
     reader.nextNode();
-    
+
     if(name == "")
         throw std::runtime_error("Missing name in style definition");
     styleRegistry.insert(std::make_pair(name, style));
 }
 
+void
+Style::toSpan(void)
+{
+    margin_right = 0;
+    margin_left = 0;
+    margin_bottom = 0;
+    margin_top = 0;
+    if (alignment == ALIGN_CENTER)
+    {   alignment = ALIGN_LEFT;}
+}
+
+
+/** @file gui/Style.cpp */
+
