@@ -35,6 +35,8 @@ class XmlReader;
 /**
  * @class Style
  */
+//TODO make distinct styles for paragraphs and spans
+
 class Style
 {
 public:
@@ -45,7 +47,7 @@ public:
     bool parseAttribute(const char* name, const char* value);
 
     std::string href;
-    
+
     std::string font_family;
     bool italic;
     bool bold;
@@ -61,6 +63,7 @@ public:
     float margin_left, margin_right, margin_top, margin_bottom;
     float width, height, min_width, min_height;
 
+    void toSpan(void); //restricts paragraph style to span style
 private:
     Color parseColor(const char* value);
 };
@@ -70,3 +73,6 @@ void parseStyleDef(XmlReader& reader);
 
 #endif
 
+
+/** @file gui/Style.hpp */
+
