@@ -22,8 +22,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * @author Matthias Braun.
  */
 
-#include <config.h>
-
 #include "SwitchComponent.hpp"
 #include "XmlReader.hpp"
 #include "ComponentLoader.hpp"
@@ -176,4 +174,7 @@ SwitchComponent::opaque(const Vector2& pos) const
     return false;
 }
 
-IMPLEMENT_COMPONENT_FACTORY(SwitchComponent);
+IMPLEMENT_COMPONENT_FACTORY(SwitchComponent)
+
+/** @file gui/SwitchComponent.cpp */
+
