@@ -15,8 +15,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <config.h>
-
 #include "TableLayout.hpp"
 
 #include <stdexcept>
@@ -463,5 +461,8 @@ TableLayout::addComponent(size_t col, size_t row, Component* component)
     cells[row * colproperties.size() + col] = Cell(childs.size()-1);
 }
 
-IMPLEMENT_COMPONENT_FACTORY(TableLayout);
+IMPLEMENT_COMPONENT_FACTORY(TableLayout)
+
+
+/** @file gui/TableLayout.cpp */
 
