@@ -17,15 +17,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
 /**
- * @file XmlReader.cpp
+ * @file gui/XmlReader.cpp
  * @brief Implement a simple XML file reader (simple wrapper around libxml2 xmlreader interface).
  * @author Matthias Braun.
  */
 
-#include <config.h>
-
-#include "XmlReader.hpp"
+#include "./XmlReader.hpp"
 
+#include "PhysfsStream/PhysfsError.hpp"
 #include <physfs.h>
 
 /**
@@ -38,12 +37,12 @@ XmlReader::XmlReader(const std::string& filename)
     PHYSFS_file* file = PHYSFS_openRead(filename.c_str());
     if(file == 0) {
         std::stringstream msg;
-        msg << "Couldn't open file '" << filename << "': " 
-            << PHYSFS_getLastError();
+        msg << "Couldn't open file '" << filename << "': "
+            << getPhysfsLastError();
         throw std::runtime_error(msg.str());
     }
     
-    reader = xmlReaderForIO(readCallback, closeCallback, file, 
+    reader = xmlReaderForIO(readCallback, closeCallback, file,
             0, 0, XML_PARSE_NONET);
     if(reader == 0) {
         PHYSFS_close(file);
@@ -74,9 +73,9 @@ int
 XmlReader::readCallback(void* context, char* buffer, int len)
 {
     PHYSFS_file* file = (PHYSFS_file*) context;
-    PHYSFS_sint64 result = PHYSFS_read(file, buffer, 1, len);
+    PHYSFS_sint64 result = PHYSFS_readBytes(file, buffer, len);
     if(result < 0) {
-        std::cerr << "Read error: " << PHYSFS_getLastError() << "\n";
+        std::cerr << "Read error: " << getPhysfsLastError() << "\n";
     }
     return (int) result;
 }
@@ -89,11 +88,13 @@ XmlReader::readCallback(void* context, char* buffer, int len)
 int
 XmlReader::closeCallback(void* context)
 {
-    PHYSFS_file* file = (PHYSFS_file*) context; 
+    PHYSFS_file* file = (PHYSFS_file*) context;
     int res = PHYSFS_close(file);
     if(res < 0) {
-        std::cerr << "Close error: " << PHYSFS_getLastError() << "\n";
+        std::cerr << "Close error: " << getPhysfsLastError() << "\n";
     }
     return res;
 }
 
+
+/** @file gui/XmlReader.cpp */
