@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 /**
  * @author Matthias Braun.
- * @file XmlReader.hpp
+ * @file gui/XmlReader.hpp
  * @brief Simple wrapper around libxml2 xmlreader interface.
  */
 
@@ -70,6 +70,11 @@ public:
     {
         xmlTextReaderNext(reader);
     }
+    
+    const xmlChar* readString()
+    {
+        return xmlTextReaderReadString(reader);
+    }
 
     class AttributeIterator 
     {
@@ -136,7 +141,7 @@ public:
             throw std::runtime_error(msg.str());
         }
 
-        // Usefull for debug sometimes...
+        // Useful for debug sometimes...
 #if 0
         for(int i = 0; i < getDepth(); ++i)
             std::cout << " ";
@@ -159,3 +164,6 @@ private:
 
 #endif
 
+
+/** @file gui/XmlReader.hpp */
+
