@@ -15,14 +15,14 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <config.h>
-
 #include "gui_interface/shared_globals.h"
 
-int module_help_flag[NUMOF_MODULES]; 
-int selected_module;	
-int sbut[NUMOF_MODULES];
+//TODO delete this file
 
+//int module_help_flag[NUMOF_MODULES];
+//int selected_module;
+//int sbut[NUMOF_MODULES];
+/*
 void highlight_module_button (int module)
 {
     (void) module;
@@ -37,4 +37,7 @@ void set_selected_module (int type)
 {
     (void) type;
 }
+*/
+
+/** @file lincity-ng/ButtonInterface.cpp */
 
