@@ -20,8 +20,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "gui/ComponentFactory.hpp"
 #include "Debug.hpp"
 
-#include <config.h>
-
 #include <stdexcept>
 
 #include "gui/Painter.hpp"
@@ -32,9 +30,29 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "gui/XmlReader.hpp"
 
 CheckButton::CheckButton()
-    : state(STATE_NORMAL), lowerOnClick(false), checked(false),
-      mclicked(false), mouseholdTicks(0)
+    : state(STATE_NORMAL), lowerOnClick(true), checked(false),
+     mclicked(false), mouseholdTicks(0)
 {
+    /* // FIXME no utput at crash
+    std::cout << "constructing: " << this << ": ";
+    std::cout.flush();
+    state = STATE_NORMAL;
+    std::cout << ".";
+    std::cout.flush();
+    lowerOnClick = false;
+    std::cout << ".";
+    std::cout.flush();
+    checked = false;
+    std::cout << ".";
+    std::cout.flush();
+    mclicked = false;
+    std::cout << ".";
+    std::cout.flush();
+    mouseholdTicks = 0;
+    std::cout << ".";
+    std::cout.flush();
+    std::cout << " done" << std::endl;
+    */
 }
 
 CheckButton::~CheckButton()
@@ -45,6 +63,8 @@ void
 CheckButton::parse(XmlReader& reader)
 {
     // parse xml attributes
+    //std::cout << "parsing Checkbutton ...";
+    //std::cout.flush();
     XmlReader::AttributeIterator iter(reader);
     while(iter.next()) {
         const char* attribute = (const char*) iter.getName();
@@ -76,7 +96,7 @@ CheckButton::parse(XmlReader& reader)
             } else if(strcmp(value, "false") == 0) {
                 uncheck();
             } else {
-                std::cerr << "Unknown value '" << value 
+                std::cerr << "Unknown value '" << value
                           << "' in check attribute."
                           << " Should be 'true' or 'false'.\n";
             }
@@ -88,7 +108,7 @@ CheckButton::parse(XmlReader& reader)
 
     // we need 6 child components
     childs.assign(6, Child());
-    
+
     // parse contents of the xml-element
     bool parseTooltip = false;
     int depth = reader.getDepth();
@@ -158,7 +178,7 @@ CheckButton::parse(XmlReader& reader)
             if(!parseTooltip)
                 continue;
 
-            const char* p = GUI_TRANSLATE((const char*) reader.getValue());  
+            const char* p = GUI_TRANSLATE((const char*) reader.getValue());
 
             // skip trailing spaces
             while(*p != 0 && isspace(static_cast<unsigned char>(*p)))
@@ -176,7 +196,7 @@ CheckButton::parse(XmlReader& reader)
                     tooltip += *p;
                 }
             }
-        }                
+        }
     }
 
     if(comp_normal().getComponent() == 0)
@@ -204,16 +224,17 @@ CheckButton::parse(XmlReader& reader)
         if(!child.getComponent())
             continue;
         Component* component = child.getComponent();
-        
+
         child.setPos( Vector2 ((width - component->getWidth())/2,
                                (height - component->getHeight())/2));
     }
+    //std::cout << " done" << std::endl;
 }
 
 void
 CheckButton::setChildImage(Child& child, XmlReader& reader)
 {
-    std::auto_ptr<Image> image(new Image());
+    std::unique_ptr<Image> image(new Image());
     image->parse(reader);
     resetChild(child, image.release());
 }
@@ -221,7 +242,7 @@ CheckButton::setChildImage(Child& child, XmlReader& reader)
 void
 CheckButton::setChildText(Child& child, XmlReader& reader)
 {
-    std::auto_ptr<Paragraph> paragraph(new Paragraph());
+    std::unique_ptr<Paragraph> paragraph(new Paragraph());
     paragraph->parse(reader);
     resetChild(child, paragraph.release());
 }
@@ -260,7 +281,7 @@ void
 CheckButton::event(const Event& event)
 {
     bool nochange=false;
-  
+
     State oldstate=state;
     switch(event.type) {
         case Event::MOUSEMOTION:
@@ -278,8 +299,7 @@ CheckButton::event(const Event& event)
             }
             break;
         case Event::MOUSEBUTTONDOWN:
-            if(!event.inside || event.mousebutton == SDL_BUTTON_WHEELUP
-                    || event.mousebutton == SDL_BUTTON_WHEELDOWN) {
+            if(!event.inside) {
               nochange=true;
               break;
             }
@@ -307,7 +327,7 @@ CheckButton::event(const Event& event)
              }
              nochange=true;
              break;
-        }    
+        }
         default:
             nochange=true;
             break;
@@ -368,23 +388,31 @@ CheckButton::draw(Painter& painter)
         case STATE_NORMAL:
             drawChild(comp_normal(), painter);
             break;
-            
+
         default:
             assert(false);
     }
-    if(lowerOnClick && state==STATE_CLICKED)
+    if(lowerOnClick)
     {
-       painter.pushTransform();
-       painter.translate(Vector2(1,1));
+        if(state == STATE_CLICKED)
+        {
+            painter.pushTransform();
+            painter.translate(Vector2(3,3));
+        }
+        else if(state == STATE_HOVER)
+        {
+            painter.pushTransform();
+            painter.translate(Vector2(1,1));
+        }
     }
     if(comp_caption().isEnabled()) {
         if(state == STATE_DISABLED && comp_disabled().isEnabled())
-            drawChild(comp_disabled(), painter);
+        {   drawChild(comp_disabled(), painter);}
         else
-            drawChild(comp_caption(), painter);
+        {   drawChild(comp_caption(), painter);}
     }
-    if(lowerOnClick && state==STATE_CLICKED)
-        painter.popTransform();
+    if(lowerOnClick && (state==STATE_CLICKED || state == STATE_HOVER))
+    {   painter.popTransform();}
 }
 
 Component *CheckButton::getCaption()
@@ -423,10 +451,13 @@ std::string CheckButton::getCaptionText()
     Paragraph *p=dynamic_cast<Paragraph*>(cm);
     if(p)
       s=p->getText();
-  }  
-  
+  }
+
   return s;
 }
 
-IMPLEMENT_COMPONENT_FACTORY(CheckButton);
+IMPLEMENT_COMPONENT_FACTORY(CheckButton)
+
+
+/** @file lincity-ng/CheckButton.cpp */
 
