@@ -30,7 +30,7 @@ class HelpWindow;
 class Game
 {
 public:
-    Game();
+    Game( SDL_Window* window );
     ~Game();
 
     MainState run();
@@ -38,7 +38,7 @@ public:
     void showHelpWindow( std::string topic );
 
 private:
-    std::auto_ptr<Component> gui;
+    std::unique_ptr<Component> gui;
     
     bool running;
     MainState quitState;
@@ -46,10 +46,14 @@ private:
     void testAllHelpFiles();
     void quickLoad();
     void quickSave();
-    std::auto_ptr<HelpWindow> helpWindow;
+    std::unique_ptr<HelpWindow> helpWindow;
+    SDL_Window* window;
 };
 
 Game* getGame();
 
 #endif
 
+
+/** @file lincity-ng/Game.hpp */
+
