@@ -23,7 +23,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "gui/Vector2.hpp"
 #include "gui/Texture.hpp"
 #include <time.h>
-#include <SDL.h> 
+#include <SDL.h>
 #include <SDL_thread.h>
 #include <SDL_image.h>
 
@@ -31,8 +31,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "MapPoint.hpp"
 #include "MiniMap.hpp"
 
-#undef DEBUG_FPS
-
 class GameView : public Component
 {
 public:
@@ -40,29 +38,29 @@ public:
     ~GameView();
 
     void parse(XmlReader& reader);
-    
+
     void draw(Painter& painter);
     void resize(float width, float height );
     void event(const Event& event);
 
     void requestRedraw();
 
-    //Show City Tile(x/y) by centering the screen 
+    //Show City Tile(x/y) by centering the screen
     void show(MapPoint point, bool redraw = true );
     MapPoint getCenter();
-        
+
     //Set Zoomlevel to default
     void resetZoom();
-    //increase Zoomlevel 
+    //increase Zoomlevel
     void zoomIn();
-    //decrease Zoomlevel 
+    //decrease Zoomlevel
     void zoomOut();
 
     //scroll the map
-    void scroll( void );
+    void scroll(float elapsedTime);
 
     //size in Tiles of marking under Cursor
-    void setCursorSize( int size ); 
+    void setCursorSize( int size );
 
     //inform GameView about change in Mini Map Mode
     void setMapMode( MiniMap::DisplayMode mMode );
@@ -73,35 +71,48 @@ public:
     //evaluate main_screen_originx and main_screen_originy
     void readOrigin( bool redraw = true );
     //set main_screen_originx and main_screen_originy
-    void writeOrigin();    
+    void writeOrigin();
 
     void printStatusMessage( std::string message );
 
+    void fetchTextures(void);
+    //convert all remaining images in ConstructionGroup::reourceMap to textures
+
     //check if tile is in city
     bool inCity( MapPoint tile );
+
+    int gameAreaMax();
+    bool textures_ready;
+    //bool economyGraph_open;
+    int remaining_images;
+
 private:
     void connectButtons();
     void buttonClicked( Button* button );
     void recenter(const Vector2& pos);
     Vector2 getScreenPoint(MapPoint point);
     MapPoint getTile(const Vector2& point);
-    void drawTile(Painter& painter, MapPoint point);
-    void drawOverlay(Painter& painter, MapPoint point);
+    void drawTile(Painter& painter, const MapPoint &point);
+    void drawTexture(Painter& painter, const MapPoint &point, GraphicsInfo *graphicsInfo);
+    void drawOverlay(Painter& painter, const MapPoint &point);
     void fillDiamond( Painter& painter, const Rect2D& rect );
     void drawDiamond( Painter& painter, const Rect2D& rect );
-    void loadTextures();
     static int gameViewThread(void* data);
-    
     void setZoom(float newzoom);
-    Texture* readTexture(const std::string& filename);
+    void zoomMouse(float factor, Vector2 mousepos);
+    bool constrainViewportPosition(bool useScrollCorrection);
     SDL_Surface* readImage(const std::string& filename);
-    void preReadCityTexture(int textureType, const std::string& filename);
+    void preReadImages(void);
+    Texture* readTexture(const std::string& filename);
+    //void loadTextures();
+    //void preReadCityTexture(int textureType, const std::string& filename);
 
-    float tileWidth, tileHeight, zoom; 
+    float tileWidth, tileHeight, zoom;
     //a virtual screen containing the whole city
     float virtualScreenWidth, virtualScreenHeight;
 
     enum {
+        SCROLL_NONE = 0x0,
         SCROLL_UP = 1,
         SCROLL_DOWN = (1 << 1),
         SCROLL_LEFT = (1 << 2),
@@ -112,6 +123,11 @@ private:
         SCROLL_DOWN_RIGHT = (1 << 7),
         SCROLL_LSHIFT = (1 << 8),
         SCROLL_RSHIFT = (1 << 9),
+        SCROLL_UP_ALL = SCROLL_UP | SCROLL_UP_LEFT | SCROLL_UP_RIGHT,
+        SCROLL_DOWN_ALL = SCROLL_DOWN | SCROLL_DOWN_LEFT | SCROLL_DOWN_RIGHT,
+        SCROLL_LEFT_ALL = SCROLL_LEFT | SCROLL_UP_LEFT | SCROLL_DOWN_LEFT,
+        SCROLL_RIGHT_ALL = SCROLL_RIGHT | SCROLL_UP_RIGHT | SCROLL_DOWN_RIGHT,
+        SCROLL_SHIFT_ALL = SCROLL_LSHIFT | SCROLL_RSHIFT,
     };
     int keyScrollState;
     int mouseScrollState;
@@ -121,31 +137,34 @@ private:
 
     int bulldozeCost( MapPoint tile );
     int buildCost( MapPoint tile );
-    
-    Texture* cityTextures[ NUM_OF_TYPES ];
-    SDL_Surface* cityImages[ NUM_OF_TYPES ];
-    Texture* blankTexture;
-    int cityTextureX[ NUM_OF_TYPES ];
-    int cityTextureY[ NUM_OF_TYPES ];
-    SDL_mutex* mTextures;
-    SDL_mutex* mThreadRunning;
+
+    GraphicsInfo blankGraphicsInfo;
+
+    //SDL_mutex* mTextures;
+    //SDL_mutex* mThreadRunning;
     SDL_Thread* loaderThread;
-    volatile bool stopThread;
-        
+    bool stopThread;
+
     MapPoint tileUnderMouse;
     Vector2 dragStart;
     bool mouseInGameView;
     bool dragging, rightButtonDown;
     Uint32 dragStartTime;
-    
-    bool roadDragging, leftButtonDown;
+    Vector2 scrollCorrection;
+
+    bool roadDragging, ctrDrag, leftButtonDown;
+    // NOTE: leftButtonDown indicates whether the middle button is down
+    //       (I didn't bother to refactor the name.)
     MapPoint startRoad;
-    
+    bool areaBulldoze;
+    bool mpsEnvOnQuery;
+    void updateMps(int x, int y);
+
     static const float defaultTileWidth;
     static const float defaultTileHeight;
     static const float defaultZoom;
 
-    bool hideHigh;
+    bool hideHigh, showTerrainHeight;
     int mapOverlay;
     MiniMap::DisplayMode mapMode;
     static const int overlayNone = 0;
@@ -154,20 +173,26 @@ private:
     static const int overlayMAX = 2;
 
     static const int gameAreaMin = 1;
-    static const int gameAreaMax = WORLD_SIDE_LEN -2;
-    void markTile( Painter& painter, MapPoint map );
+
+    void markTile( Painter& painter, const MapPoint &tile );
 
     int cursorSize;
     bool buttonsConnected;
 
     MapPoint realTile( MapPoint tile );
     std::string lastStatusMessage;
+
+    SDL_Cursor *panningCursor;
+    void setPanningCursor();
+    void setDefaultCursor();
 };
 
 GameView* getGameView();
-  
+
 Uint32 autoScroll( Uint32 interval, void *param );
 static const int scrollBorder = 5;
 
 #endif
 
+
+/** @file lincity-ng/GameView.hpp */
