@@ -32,11 +32,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "gui/Event.hpp"
 #include "gui/Desktop.hpp"
 #include "gui/Button.hpp"
+#include "gui/Painter.hpp"
 #include "gui/callback/Callback.hpp"
 
 #include "gui_interface/shared_globals.h"
-#include "lincity/lin-city.h"
-#include "lincity/fileutil.h"
 
 #include "CheckButton.hpp"
 
@@ -45,20 +44,27 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Config.hpp"
 #include "Sound.hpp"
 #include "GameView.hpp"
+#include "Game.hpp"
 #include "MainLincity.hpp"
 #include "readdir.hpp"
+#include "lincity/loadsave.h"
 
 #include "tinygettext/gettext.hpp"
 
-extern void new_city(int *originx, int *originy, int random_village);
+#include "lincity/init_game.h"
 
-MainMenu::MainMenu()
+extern std::string autoLanguage;
+
+MainMenu::MainMenu(SDL_Window* _window)
+    : window(_window)
 {
     loadMainMenu();
     switchMenu(mainMenu.get());
     baseName = "";
     lastClickTick = 0;
     doubleClickButtonName = "";
+    mFilename = "";
+    baseName = "";
 }
 
 MainMenu::~MainMenu()
@@ -68,14 +74,14 @@ MainMenu::~MainMenu()
 void
 MainMenu::loadMainMenu()
 {
-    if(mainMenu.get() == 0) {
+    if(mainMenu.get() == 0)
+    {
         mainMenu.reset(loadGUIFile("gui/mainmenu.xml"));
-
         // connect signals
         Button* quitButton = getButton(*mainMenu, "QuitButton");
         quitButton->clicked.connect(
                 makeCallback(*this, &MainMenu::quitButtonClicked));
-        Button* continueButton = getButton(*mainMenu, "ContinueButton"); 
+        Button* continueButton = getButton(*mainMenu, "ContinueButton");
         continueButton->clicked.connect(
                 makeCallback(*this, &MainMenu::continueButtonClicked));
         Button* newGameButton = getButton(*mainMenu, "NewGameButton");
@@ -93,26 +99,44 @@ MainMenu::loadMainMenu()
         Button* optionsButton = getButton(*mainMenu, "OptionsButton");
         optionsButton->clicked.connect(
                 makeCallback(*this, &MainMenu::optionsButtonClicked));
- 
+
     }
 
-    mainMenu->resize(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
+    int width = 0, height = 0;
+    SDL_GetWindowSize(window, &width, &height);
+    mainMenu->resize(width, height);
 }
 
 void MainMenu::fillNewGameMenu()
 {
+#if 1
+  //Do not remove it!
+  //It is need for localization
+  //
+  // If you going to remove this, you must
+  // get names from data/opening/*scn files,
+  // and update messages.pot from script.
+  (void)N_("Rocket_98");
+  (void)N_("Beach");
+  (void)N_("bad_times");
+  (void)N_("extreme_arid");
+  (void)N_("extreme_wetland");
+  (void)N_("good_times");
+#endif
   const std::string buttonNames[]={"File0","File1","File2","File3","File4","File5"};
-  
+
   char **files= PHYSFS_enumerateFiles("opening");
-  
+
   char **fptr=files;
 
-  fileMap.clear(); 
- 
+  CheckButton *button;
+
+  fileMap.clear();
+
   for(int i=0;i<6;i++)
   {
-    CheckButton *button=getCheckButton(*newGameMenu.get(),buttonNames[i]);
-    
+    button=getCheckButton(*newGameMenu.get(),buttonNames[i]);
+
     button->clicked.connect(makeCallback(*this,&MainMenu::selectLoadGameButtonClicked));
     while(*fptr)
     {
@@ -128,7 +152,7 @@ void MainMenu::fillNewGameMenu()
       }
       // save real name
       fileMap.insert(std::pair<std::string, std::string>(buttonNames[i], f ));
-      // use translated name for caption 
+      // use translated name for caption
       button->setCaptionText(_(f.c_str()));
       fptr++;
     }
@@ -136,26 +160,42 @@ void MainMenu::fillNewGameMenu()
       button->setCaptionText("");
   }
   PHYSFS_freeList(files);
+
+  button=getCheckButton(*newGameMenu.get(),"WithVillage");
+  button->check();
+  //button->setCaptionText(_("random empty board"));
+  //button->clicked.connect(makeCallback(*this,&MainMenu::selectLoadGameButtonClicked));
+
+  button=getCheckButton(*newGameMenu.get(),"RiverDelta");
+  button->setCaptionText(_("river delta"));
+  button->clicked.connect(makeCallback(*this,&MainMenu::selectLoadGameButtonClicked));
+
+  button=getCheckButton(*newGameMenu.get(),"DesertArea");
+  button->setCaptionText(_("semi desert"));
+  button->clicked.connect(makeCallback(*this,&MainMenu::selectLoadGameButtonClicked));
+
+  button=getCheckButton(*newGameMenu.get(),"TemperateArea");
+  button->setCaptionText(_("temperate"));
+  button->clicked.connect(makeCallback(*this,&MainMenu::selectLoadGameButtonClicked));
+
+  button=getCheckButton(*newGameMenu.get(),"SwampArea");
+  button->setCaptionText(_("swamp"));
+  button->clicked.connect(makeCallback(*this,&MainMenu::selectLoadGameButtonClicked));
+
   return;
-  /* Is there a better way to add filenames to the directory? */
-  _("good_times");
-  _("bad_times");
-  _("Beach");
-  _("extreme_arid");
-  _("extreme_wetland");
 }
 
 void MainMenu::fillLoadMenu( bool save /*= false*/ )
 {
     const std::string buttonNames[]={"File0","File1","File2","File3","File4","File5"};
-  
+
     char** rc = PHYSFS_enumerateFiles("/");
 
     char* curfile;
     CheckButton *button;
 
     for(int i=0;i<6;i++) {
-    	char* recentfile = NULL;
+        char* recentfile = NULL;
         PHYSFS_sint64 t = 0;
 
         std::stringstream filestart;
@@ -165,8 +205,8 @@ void MainMenu::fillLoadMenu( bool save /*= false*/ )
         } else {
             button = getCheckButton(*loadGameMenu.get(),buttonNames[i]);
         }
-        //make sure Button is connected only once 
-        button->clicked.clear(); 
+        //make sure Button is connected only once
+        button->clicked.clear();
         if( save )
             button->clicked.connect(makeCallback(*this,&MainMenu::selectSaveGameButtonClicked));
         else {
@@ -174,31 +214,30 @@ void MainMenu::fillLoadMenu( bool save /*= false*/ )
         }
         for(char** i = rc; *i != 0; i++){
             curfile = *i;
-            if(std::string( curfile ).find( filestart.str() ) == 0 ) {
+            if(std::string( curfile ).find( filestart.str() ) != 0 ) {
                 // && !( curfile->d_type & DT_DIR  ) ) is not portable. So
                 // don't create a directoy named 2_ in a savegame-directory or
                 // you can no longer load from slot 2.
-    	        if (t == 0) {
-                    recentfile = curfile;
-                    t = PHYSFS_getLastModTime(recentfile);
-              } else {
-                    if (PHYSFS_getLastModTime(curfile) > t) {
-#ifdef DEBUG
-                        fprintf(stderr," %s is more recent than previous %s\n",
-                                          curfile, recentfile);
-#endif
-                        recentfile = curfile;
-                        t = PHYSFS_getLastModTime(recentfile);
-                    }
-                }
+                continue;
+            }
+            PHYSFS_Stat stat;
+            int err = PHYSFS_stat(curfile, &stat);
+            if(!err) {
+                std::cerr << "could not stat file: " <<
+                    curfile << std::endl;
+                continue;
+            }
+            if (!recentfile || stat.modtime > t) {
+                recentfile = curfile;
+                t = stat.modtime;
             }
         }
 #ifdef DEBUG
         fprintf(stderr,"Most recent file: %s\n\n",recentfile);
 #endif
 
-        if(t != 0) {
-            std::string f= recentfile;
+        if(recentfile) {
+            std::string f = recentfile;
             button->setCaptionText(f);
         } else {
             button->setCaptionText(_("empty"));
@@ -214,34 +253,32 @@ MainMenu::loadNewGameMenu()
 
         // connect signals
         Button* startButton = getButton(*newGameMenu, "StartButton");
-        startButton->clicked.connect(
-                makeCallback(*this, &MainMenu::newGameStartButtonClicked));
+        startButton->clicked.connect(makeCallback(*this, &MainMenu::newGameStartButtonClicked));
+
         Button* backButton = getButton(*newGameMenu, "BackButton");
-        backButton->clicked.connect(
-                makeCallback(*this, &MainMenu::newGameBackButtonClicked));
-        Button* startBareButton = getButton(*newGameMenu, "StartBareButton");
-        startBareButton->clicked.connect(
-                makeCallback(*this, &MainMenu::newGameStartBareButtonClicked));
-        Button* startVillageButton = getButton(*newGameMenu, "StartVillageButton");
-        startVillageButton->clicked.connect(
-                makeCallback(*this, &MainMenu::newGameStartVillageClicked));
+        backButton->clicked.connect(makeCallback(*this, &MainMenu::newGameBackButtonClicked));
+
+
         fillNewGameMenu();
     }
-
-    newGameMenu->resize(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
+    int width = 0, height = 0;
+    SDL_GetWindowSize(window, &width, &height);
+    newGameMenu->resize(width, height);
 }
 
 void
 MainMenu::loadCreditsMenu()
 {
-    if(creditsMenu.get() == 0) {
+    if(creditsMenu.get() == 0)
+    {
         creditsMenu.reset(loadGUIFile("gui/credits.xml"));
         Button* backButton = getButton(*creditsMenu, "BackButton");
         backButton->clicked.connect(
                 makeCallback(*this, &MainMenu::creditsBackButtonClicked));
     }
-
-    creditsMenu->resize(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
+    int width = 0, height = 0;
+    SDL_GetWindowSize(window, &width, &height);
+    creditsMenu->resize(width, height);
 }
 
 void
@@ -267,9 +304,25 @@ MainMenu::loadOptionsMenu()
         currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
         currentCheckButton = getCheckButton(*optionsMenu, "TrackNext");
         currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
-        
+        currentCheckButton = getCheckButton(*optionsMenu, "ResolutionPrev");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "ResolutionNext");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "WorldLenPrev");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "WorldLenNext");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "LanguagePrev");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "LanguageNext");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "BinaryMode");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+        currentCheckButton = getCheckButton(*optionsMenu, "SeedMode");
+        currentCheckButton->clicked.connect( makeCallback(*this, &MainMenu::optionsMenuButtonClicked));
+
         Button* currentButton = getButton(*optionsMenu, "BackButton");
-        currentButton->clicked.connect( makeCallback(*this, &MainMenu::creditsBackButtonClicked));
+        currentButton->clicked.connect( makeCallback(*this, &MainMenu::optionsBackButtonClicked));
     }
     //adjust checkbutton-states
     if( getConfig()->musicEnabled ){
@@ -287,11 +340,39 @@ MainMenu::loadOptionsMenu()
     } else {
         getCheckButton(*optionsMenu, "Fullscreen")->uncheck();
     }
+    if (binary_mode)
+    {   getCheckButton(*optionsMenu, "BinaryMode")->check();}
+    else
+    {   getCheckButton(*optionsMenu, "BinaryMode")->uncheck();}
+    if (seed_compression)
+    {   getCheckButton(*optionsMenu, "SeedMode")->check();}
+    else
+    {   getCheckButton(*optionsMenu, "SeedMode")->uncheck();}
     //current background track
     musicParagraph = getParagraph( *optionsMenu, "musicParagraph");
-    musicParagraph->setText(getConfig()->playSongName);
+    musicParagraph->setText(getSound()->currentTrack.title);
 
-    optionsMenu->resize(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
+
+    int width = 0, height = 0;
+    SDL_GetWindowSize(window, &width, &height);
+
+    std::stringstream mode;
+    if (getConfig()->useFullScreen) {
+        mode << "fullscreen";
+    } else {
+        mode << width << "x" << height;
+    }
+    getParagraph( *optionsMenu, "resolutionParagraph")->setText(mode.str());
+    mode.str("");
+    mode << world.len();
+    getParagraph( *optionsMenu, "WorldLenParagraph")->setText(mode.str());
+    languageParagraph = getParagraph( *optionsMenu, "languageParagraph");
+    currentLanguage = getConfig()->language;
+    languageParagraph->setText( getConfig()->language );
+    languages = dictionaryManager->get_languages();
+    languages.insert( "autodetect" );
+    languages.insert( "en" ); // English is the default when no translation is used
+    optionsMenu->resize(getConfig()->videoX, getConfig()->videoY); //(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
 }
 
 void
@@ -311,7 +392,7 @@ MainMenu::loadLoadGameMenu()
 
     // fill in file-names into slots
     fillLoadMenu();
-    loadGameMenu->resize(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
+    loadGameMenu->resize(getConfig()->videoX, getConfig()->videoY); //(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
 }
 
 void
@@ -330,8 +411,7 @@ MainMenu::loadSaveGameMenu()
         // fill in file-names into slots
         fillLoadMenu( true );
     }
-
-    saveGameMenu->resize(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
+    saveGameMenu->resize(getConfig()->videoX, getConfig()->videoY); //(SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h);
 }
 
 
@@ -340,12 +420,15 @@ MainMenu::selectLoadGameButtonClicked(CheckButton* button, int i){
     selectLoadSaveGameButtonClicked( button , i,  false );
 }
 
-void 
+void
 MainMenu::selectSaveGameButtonClicked(CheckButton* button, int i){
     selectLoadSaveGameButtonClicked( button , i, true );
 }
 
-void 
+/**
+ * Handle RadioButtons in load, save and new game dialog
+ */
+void
 MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
 {
     std::string fc=button->getCaptionText();
@@ -356,18 +439,18 @@ MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
             fc = iter->second;
         }
     }
-  
+
     std::string file="";
-    
+
     /* I guess this should be the proper way of selecting in the menu.
        Everytime we check a new button the last one gets unchecked.
-       If the button checked is an empty one, nothing should be opened 
+       If the button checked is an empty one, nothing should be opened
        Could be done the other way around: the first time an existing item
        is selected in the menu, an empty one could never be checked again.
        Anyway I don't think both should be checked, when an empty is checked
        after an existing one.
     */
-       
+
     const std::string bs[]={"File0","File1","File2","File3","File4","File5",""};
     for(int i=0;std::string(bs[i]).length();i++) {
         CheckButton *b=getCheckButton(*currentMenu,bs[i]);
@@ -378,28 +461,42 @@ MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
         }
     }
 
+    if( newGameMenu.get()==currentMenu ) {
+        const std::string rnd[]={"RiverDelta","DesertArea","TemperateArea","SwampArea",""};
+        for(int i=0;std::string(rnd[i]).length();i++) {
+            CheckButton *b=getCheckButton(*currentMenu,rnd[i]);
+            if(b->getName()!=button->getName()){
+                b->uncheck();
+            } else {
+                b->check();
+                fc = rnd[i];
+            }
+        }
+    }
+
+
     if( !fc.length()) {
         mFilename = "";
         return;
     }
-    
+
     baseName = fc;
     if(newGameMenu.get()==currentMenu ) {
         file=std::string("opening/")+fc+".scn";
     } else {
         file=fc;
     }
-    
+
     mFilename="";
     if(newGameMenu.get()!=currentMenu) {
-        slotNr = 1 + atoi( 
+        slotNr = 1 + atoi(
                 const_cast<char*>(button->getName().substr(4).c_str()) );
         if( file.length() == 0){
             mFilename = "";
             return;
         }
     }
-    
+
     mFilename+=file;
     Uint32 now = SDL_GetTicks();
 
@@ -410,7 +507,7 @@ MainMenu::selectLoadSaveGameButtonClicked(CheckButton* button , int, bool save )
         lastClickTick = 0;
         doubleClickButtonName = "";
         if( newGameMenu.get() == currentMenu ) {
-            //load scenario 
+            //load scenario
             newGameStartButtonClicked( 0 );
         } else {
             //load game
@@ -430,19 +527,19 @@ void MainMenu::optionsMenuButtonClicked( CheckButton* button, int ){
     } else if( buttonName == "MusicVolumePlus"){
         int newVolume = getConfig()->musicVolume + 5;
         if( newVolume > 100 ){
-           newVolume = 100; 
+           newVolume = 100;
         }
         if( getConfig()->musicVolume != newVolume ){
-            getSound()->setMusicVolume( newVolume ); 
+            getSound()->setMusicVolume( newVolume );
             getSound()->playSound("Click");
         }
     } else if( buttonName == "MusicVolumeMinus"){
         int newVolume = getConfig()->musicVolume -5;
         if( newVolume < 0 ){
-           newVolume = 0; 
+           newVolume = 0;
         }
         if( getConfig()->musicVolume != newVolume ){
-            getSound()->setMusicVolume( newVolume ); 
+            getSound()->setMusicVolume( newVolume );
             getSound()->playSound("Click");
         }
     } else if( buttonName == "SoundFX"){
@@ -451,87 +548,196 @@ void MainMenu::optionsMenuButtonClicked( CheckButton* button, int ){
     } else if( buttonName == "FXVolumePlus"){
         int newVolume = getConfig()->soundVolume + 5;
         if( newVolume > 100 ){
-           newVolume = 100; 
+           newVolume = 100;
         }
         if( getConfig()->soundVolume != newVolume ){
-            getSound()->setSoundVolume( newVolume ); 
+            getSound()->setSoundVolume( newVolume );
             getSound()->playSound("Click");
         }
     } else if( buttonName == "FXVolumeMinus"){
         int newVolume = getConfig()->soundVolume - 5;
         if( newVolume < 0 ){
-           newVolume = 0; 
+           newVolume = 0;
         }
         if( getConfig()->soundVolume != newVolume ){
-            getSound()->setSoundVolume( newVolume ); 
+            getSound()->setSoundVolume( newVolume );
             getSound()->playSound("Click");
         }
+    } else if( buttonName == "ResolutionPrev"){
+        changeResolution(false);
+    } else if( buttonName == "ResolutionNext"){
+        changeResolution(true);
+    } else if( buttonName == "WorldLenPrev"){
+        changeWorldLen(false);
+    } else if( buttonName == "WorldLenNext"){
+        changeWorldLen(true);
+    } else if( buttonName == "LanguagePrev"){
+        changeLanguage(false);
+    } else if( buttonName == "LanguageNext"){
+        changeLanguage(true);
     } else if( buttonName == "Fullscreen"){
         getSound()->playSound("Click");
-        getConfig()->useFullScreen = !getConfig()->useFullScreen; 
-        if( getConfig()->restartOnChangeScreen ){
+        getConfig()->useFullScreen = !getConfig()->useFullScreen;
+        getConfig()->save();
+        if( getConfig()->restartOnChangeScreen )
+        {
             quitState = RESTART;
             running = false;
-        } else {
-            initVideo(getConfig()->videoX, getConfig()->videoY);
+        }
+        else
+        {
+            int width = 0, height = 0;
+            SDL_GetWindowSize(window, &width, &height);
+            resizeVideo(width, height, getConfig()->useFullScreen);
+            // switching to fullscreen may change window size again
+            SDL_GetWindowSize(window, &width, &height);
+            currentMenu->resize(width, height);
             loadOptionsMenu();
         }
     } else if( buttonName == "TrackPrev"){
         changeTrack(false);
     } else if( buttonName == "TrackNext"){
         changeTrack(true);
+    } else if( buttonName == "BinaryMode"){
+        binary_mode = !binary_mode;
+    } else if( buttonName == "SeedMode"){
+        seed_compression = !seed_compression;
     } else {
         std::cerr << "MainMenu::optionsMenuButtonClicked " << buttonName << " unknown Button!\n";
-    }    
+    }
+}
+
+/** Changes the displayed resolution in the options menu.
+This does not actually change the resolution. initVideo has to be called to do this.
+@param next if true change to the next resolution in the list; otherwise change to the previous one
+@todo sort modes before in ascending order and remove unsupported modes like 640x480
+*/
+void MainMenu::changeResolution(bool next) {
+    if (getConfig()->useFullScreen) {
+        /* Resolution changes have no effect in desktop fullscreen mode */
+        return;
+    }
+
+    // Create a list of candidate resolutions, including a few fallbacks in
+    // case the window system doesn't provide any
+    std::vector<std::pair<int, int>> resolutions;
+    resolutions.push_back(std::pair<int, int>(800,600));
+    resolutions.push_back(std::pair<int, int>(1024,768));
+    resolutions.push_back(std::pair<int, int>(1280,1024));
+
+    int display = SDL_GetWindowDisplayIndex(window);
+    int nmodes = SDL_GetNumDisplayModes(display);
+    for (int i = -1; i < nmodes; ++i) {
+        SDL_DisplayMode mode;
+        if (i >= 0) {
+            if (SDL_GetDisplayMode(display, i, &mode) < 0) {
+                std::cerr << "Error: SDL failed to get mode " << i << " for display " << display << "!\n";
+                continue;
+            }
+        } else {
+            /* Special case: half the current display size */
+            if (SDL_GetCurrentDisplayMode(display, &mode) < 0) {
+                std::cerr << "Error: SDL failed to get current mode for display " << display << "!\n";
+                continue;
+            }
+            mode.w /= 2;
+            mode.h /= 2;
+        }
+        bool in_list = false;
+        for (size_t j = 0; j < resolutions.size(); j++) {
+            if (resolutions[j].first == mode.w && resolutions[j].second == mode.h) {
+                in_list = true;
+                break;
+            }
+        }
+        if (!in_list) {
+            resolutions.push_back(std::pair<int, int>(mode.w, mode.h));
+        }
+    }
+    std::sort(resolutions.begin(), resolutions.end());
+
+    const int width = getConfig()->videoX;
+    const int height = getConfig()->videoY;
+    int closest_mode = 0;
+    int min_cost = 1000000000;
+    for (size_t i = 0; i < resolutions.size(); ++i) {
+        int cost = 2 * abs(resolutions[i].first - width) + abs(resolutions[i].second - height);
+        if (cost < min_cost) {
+            closest_mode = int(i);
+            min_cost = cost;
+        }
+    }
+
+    std::string currentMode = getParagraph( *optionsMenu, "resolutionParagraph")->getText();
+
+    std::stringstream mode;
+    mode.str("");
+    mode << resolutions[closest_mode].first << "x" << resolutions[closest_mode].second;
+
+    int new_mode = closest_mode + (next ? 1 : -1);
+    /* Wrap around */
+    if (new_mode < 0) {
+        new_mode = int(resolutions.size()) - 1;
+    } else if (new_mode >= int(resolutions.size())) {
+        new_mode = 0;
+    }
+
+    mode.str("");
+    mode << resolutions[new_mode].first << "x" << resolutions[new_mode].second;
+
+    getSound()->playSound("Click");
+    getParagraph( *optionsMenu, "resolutionParagraph")->setText(mode.str());
+    getConfig()->videoX = resolutions[new_mode].first;
+    getConfig()->videoY = resolutions[new_mode].second;
+}
+
+void
+MainMenu::changeWorldLen(bool next)
+{
+    std::ostringstream os;
+    int new_len;
+    new_len = world.len()+(next?25:-25);
+    world.len(new_len);
+    os << world.len();
+    getParagraph( *optionsMenu, "WorldLenParagraph")->setText(os.str());
 }
 
 void
 MainMenu::changeTrack( bool next)
 {
-    std::string filename;
-    std::string directory = "music/";
-    std::string fullname;
-    std::string currentname = getConfig()->playSongName;
-    std::string prevname = currentname;
-    std::string nextname = currentname;
-
-    bool hit = false;
-
-    char **files= PHYSFS_enumerateFiles(directory.c_str());
-    char **fptr=files;
-    while(*fptr)
-    {
-        fullname = directory;
-        fullname.append( *fptr );
-        filename.assign( *fptr );
-        
-        if(!PHYSFS_isDirectory(fullname.c_str())){
-            if( filename == currentname ){
-                hit = true;
-            } else if ( !hit ){
-                prevname = filename; 
-            } else {
-                nextname = filename;
-                break;
-            }
-        }
-        fptr++;
-    }
-    PHYSFS_freeList(files);
-
     if(next){
-        if( nextname != currentname){
-            getSound()->playSound("Click");
-            getSound()->playMusic(nextname);
-        }
+        getSound()->playSound("Click");
+        getSound()->changeTrack(NEXT_TRACK);
+
     } else {
-        if( prevname != currentname){
-            getSound()->playSound("Click");
-            getSound()->playMusic(prevname);
-        }
+        getSound()->playSound("Click");
+        getSound()->changeTrack(PREV_TRACK);
     }
-    musicParagraph->setText(getConfig()->playSongName);
+    musicParagraph->setText(getSound()->currentTrack.title);
 }
+
+void
+MainMenu::changeLanguage( bool next)
+{
+    std::set<std::string>::iterator i = languages.find( getConfig()->language );
+    if( next ){ // next language in set
+        i++;
+        if( i == languages.end() ){
+            i = languages.begin();
+        }
+    } else { // previous
+        if( i == languages.begin() ){
+            i = languages.end();
+        }
+        i--;
+    }
+
+    std::string newLang = *i;
+    languageParagraph->setText( newLang );
+    getConfig()->language = newLang;
+    getSound()->playSound("Click");
+}
+
 void
 MainMenu::quitButtonClicked(Button* )
 {
@@ -545,7 +751,10 @@ MainMenu::switchMenu(Component* newMenu)
 {
     currentMenu = dynamic_cast<Desktop*> (newMenu);
     if(!currentMenu)
-        throw std::runtime_error("Menu Component is not a Desktop");
+    {   throw std::runtime_error("Menu Component is not a Desktop");}
+    int width = 0, height = 0;
+    SDL_GetWindowSize(window, &width, &height);
+    currentMenu->resize(width, height);
 }
 
 void
@@ -570,6 +779,21 @@ MainMenu::continueButtonClicked(Button* )
     getSound()->playSound( "Click" );
     quitState = INGAME;
     running = false;
+    //only act if world is still clean
+    if (!world.dirty)
+    {
+        //load current game if it exists
+        if( ! loadCityNG( std::string("9_currentGameNG.scn.gz") )  &&
+            ! loadCityNG( std::string("9_currentGameNG.scn") ) )
+        {
+            city_settings  city;
+            city.with_village  = true;
+            city.without_trees = false;
+
+            //by default create a new City
+            new_city( &main_screen_originx, &main_screen_originy, &city);
+        }
+    }
 }
 
 void
@@ -592,8 +816,11 @@ void
 MainMenu::saveGameButtonClicked(Button* )
 {
     getSound()->playSound( "Click" );
-    loadSaveGameMenu();
-    switchMenu(saveGameMenu.get());
+    if(getGame())
+    {
+        loadSaveGameMenu();
+        switchMenu(saveGameMenu.get());
+    }
 }
 
 void
@@ -605,37 +832,90 @@ MainMenu::creditsBackButtonClicked(Button* )
 }
 
 void
-MainMenu::newGameStartButtonClicked(Button* )
+MainMenu::optionsBackButtonClicked(Button* )
 {
-    getSound()->playSound( "Click" );
-    if( loadCityNG( mFilename ) ){
-    	strcpy (given_scene, baseName.c_str());
-        quitState = INGAME;
+    getConfig()->save();
+    int width = 0, height = 0;
+    SDL_GetWindowSize(window, &width, &height);
+    if( getConfig()->videoX != width || getConfig()->videoY != height )
+    {
+        if( getConfig()->restartOnChangeScreen )
+        {
+            quitState = RESTART;
+            running = false;
+        }
+        else
+        {
+            resizeVideo( getConfig()->videoX, getConfig()->videoY, getConfig()->useFullScreen);
+            gotoMainMenu();
+        }
+    }
+    else if( currentLanguage != getConfig()->language )
+    {
+#if defined (WIN32)
+        _putenv_s("LINCITY_LANG", "");
+#else
+        unsetenv("LINCITY_LANG");
+#endif
+        quitState = RESTART;
         running = false;
     }
-    mFilename = "empty"; //don't erase scenarios later 
+    else
+    {
+        gotoMainMenu();
+    }
 }
 
+/**
+ * Either create selected random terrain or load a scenario.
+ **/
 void
-MainMenu::newGameStartBareButtonClicked(Button* )
+MainMenu::newGameStartButtonClicked(Button* )
 {
+    if( mFilename.empty() ){
+        // std::cout << "nothing selected\n";
+        return;
+    }
     getSound()->playSound( "Click" );
-    new_city( &main_screen_originx, &main_screen_originy, 0 );
-    GameView* gv = getGameView();
-    if( gv ){ gv->readOrigin(); }
-    quitState = INGAME;
-    running = false;
-}
 
-void
-MainMenu::newGameStartVillageClicked(Button* )
-{
-    getSound()->playSound( "Click" );
-    new_city( &main_screen_originx, &main_screen_originy, 1 );
-    GameView* gv = getGameView();
-    if( gv ){ gv->readOrigin(); }
-    quitState = INGAME;
-    running = false;
+    city_settings  city_obj;
+    city_settings *city=&city_obj;
+
+    city->with_village  = (getCheckButton(*currentMenu,"WithVillage" )->state == CheckButton::STATE_CHECKED);
+    city->without_trees = (getCheckButton(*currentMenu,"WithoutTrees")->state == CheckButton::STATE_CHECKED);
+
+    if( baseName == "RiverDelta" ){
+        new_city( &main_screen_originx, &main_screen_originy, city);
+        GameView* gv = getGameView();
+        if( gv ){ gv->readOrigin(); }
+        quitState = INGAME;
+        running = false;
+    } else if( baseName == "DesertArea" ){
+        new_desert_city( &main_screen_originx, &main_screen_originy, city);
+        GameView* gv = getGameView();
+        if( gv ){ gv->readOrigin(); }
+        quitState = INGAME;
+        running = false;
+    } else if( baseName == "TemperateArea" ){
+        new_temperate_city( &main_screen_originx, &main_screen_originy, city);
+        GameView* gv = getGameView();
+        if( gv ){ gv->readOrigin(); }
+        quitState = INGAME;
+        running = false;
+    } else if( baseName == "SwampArea" ){
+        new_swamp_city( &main_screen_originx, &main_screen_originy, city);
+        GameView* gv = getGameView();
+        if( gv ){ gv->readOrigin(); }
+        quitState = INGAME;
+        running = false;
+    } else {
+        if( loadCityNG( mFilename ) ){
+            strcpy (given_scene, baseName.c_str());
+            quitState = INGAME;
+            running = false;
+        }
+    }
+    mFilename = "empty"; //don't erase scenarios later
 }
 
 void
@@ -651,7 +931,7 @@ MainMenu::loadGameBackButtonClicked(Button* )
 {
     getSound()->playSound( "Click" );
     loadMainMenu();
-    switchMenu(mainMenu.get());   
+    switchMenu(mainMenu.get());
 }
 
 void
@@ -659,7 +939,7 @@ MainMenu::gotoMainMenu()
 {
     getSound()->playSound( "Click" );
     loadMainMenu();
-    switchMenu(mainMenu.get());   
+    switchMenu(mainMenu.get());
 }
 
 void
@@ -676,10 +956,8 @@ void
 MainMenu::loadGameSaveButtonClicked(Button *)
 {
     getSound()->playSound( "Click" );
-    if( file_exists( const_cast<char*>(mFilename.c_str()) ) ){
-        std::cout << "remove( " << mFilename << ")\n";
-        remove( mFilename.c_str() );
-    }
+    std::cout << "remove( " << mFilename << ")\n";
+    remove( mFilename.c_str() );
     /* Build filename */
     std::stringstream newStart;
     newStart << slotNr << "_Y";
@@ -691,26 +969,27 @@ MainMenu::loadGameSaveButtonClicked(Button *)
     newStart << tech_level/10000;
     newStart << "_Cash";
     if (total_money >= 0)
-    	newStart << "+";
+    {   newStart << "+";}
     else
-    	newStart << "-";
+    {   newStart << "-";}
     newStart << std::setfill('0') << std::setw(3);
     int money = abs(total_money);
     if (money > 1000000000)
-        newStart << money/1000000000 << "G";  
+    {   newStart << money/1000000000 << "G";}
     else if (money > 1000000)
-        newStart << money/1000000 << "M";  
+    {   newStart << money/1000000 << "M";}
     else  if(money > 1000)
-        newStart << money/1000 << "K"; 
+    {   newStart << money/1000 << "K";}
     else
-        newStart << money/1 << "_";
- 
+    {   newStart << money << "_";}
+
     newStart << "_P";
     newStart << std::setfill('0') << std::setw(5);
     newStart << housed_population + people_pool;
-    std::string newFilename( newStart.str() ); 
+    std::string newFilename( newStart.str() );
     saveCityNG( newFilename );
     fillLoadMenu( true );
+    gotoMainMenu();
 }
 
 
@@ -720,19 +999,39 @@ MainMenu::run()
     SDL_Event event;
     running = true;
     quitState = QUIT;
-    Uint32 ticks = SDL_GetTicks();
-    
+    Uint32 fpsTicks = SDL_GetTicks();
+    Uint32 lastticks = fpsTicks;
+    Uint32 lastRedrawTicks = fpsTicks;
     int frame = 0;
-    while(running) {
-        while(SDL_PollEvent(&event)) {
+    while(running)
+    {
+        if(SDL_WaitEventTimeout(&event, 100))
+        {
             switch(event.type) {
-                case SDL_VIDEORESIZE:
-                    initVideo(event.resize.w, event.resize.h);
-                    currentMenu->resize(event.resize.w, event.resize.h);
+                case SDL_WINDOWEVENT:
+                    if (event.window.event == SDL_WINDOWEVENT_SIZE_CHANGED) {
+                        videoSizeChanged(event.window.data1, event.window.data2);
+                        currentMenu->resize(event.window.data1, event.window.data2);
+                        getConfig()->videoX = event.window.data1;
+                        getConfig()->videoY = event.window.data2;
+
+                        if(currentMenu == optionsMenu.get())//update resolution display
+                        {
+                            std::stringstream mode;
+                            mode.str("");
+                            if (getConfig()->useFullScreen) {
+                                mode << "fullscreen";
+                            } else {
+                                mode << event.window.data1 << "x" << event.window.data2;
+                            }
+                            getParagraph( *optionsMenu, "resolutionParagraph")->setText(mode.str());
+                        }
+                    }
                     break;
                 case SDL_MOUSEMOTION:
                 case SDL_MOUSEBUTTONUP:
                 case SDL_MOUSEBUTTONDOWN:
+                case SDL_MOUSEWHEEL:
                 case SDL_KEYDOWN:{
                     Event gui_event(event);
                     currentMenu->event(gui_event);
@@ -751,14 +1050,6 @@ MainMenu::run()
                     currentMenu->event(gui_event);
                     break;
                 }
-                case SDL_VIDEOEXPOSE:
-                    currentMenu->resize( currentMenu->getWidth(), currentMenu->getHeight() );
-                    break;
-                case SDL_ACTIVEEVENT:
-                    if( event.active.gain == 1 ){
-                        currentMenu->resize( currentMenu->getWidth(), currentMenu->getHeight() );
-                    }
-                    break;
                 case SDL_QUIT:
                     running = false;
                     quitState = QUIT;
@@ -768,22 +1059,37 @@ MainMenu::run()
             }
         }
 
-        SDL_Delay(10); // give the CPU time to relax... (we are in main menu)
+        // create update Event
+        Uint32 ticks = SDL_GetTicks();
+        float elapsedTime = ((float) (ticks - lastticks)) / 1000.0;
+        currentMenu->event(Event(elapsedTime));
+        lastticks = ticks;
+
+        /* We unconditionally redraw every ~100 ms as workaround for an SDL bug
+         * under Wayland, in which window resizing is not communicated to the
+         * program until it redraws the window. When this bug is no longer
+         * present, this behavior should be safe to remove */
+        if (ticks - lastRedrawTicks > 90) {
+             currentMenu->reLayout();
+        }
 
         if(currentMenu->needsRedraw()) {
             currentMenu->draw(*painter);
-            flipScreenBuffer();
-        } 
+            painter->updateScreen();
+            lastRedrawTicks = ticks;
+        }
 
         frame++;
-        if(SDL_GetTicks() - ticks > 1000) {
+        if(ticks - fpsTicks > 1000) {
 #ifdef DEBUG_FPS
-            printf("FPS: %d.\n", frame);
+            printf("MainMenu FPS: %d.\n", (frame*1000) / (ticks - fpsTicks));
 #endif
             frame = 0;
-            ticks = SDL_GetTicks();
+            fpsTicks = ticks;
         }
     }
 
     return quitState;
 }
+
+/** @file lincity-ng/MainMenu.cpp */
