@@ -20,10 +20,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "gui/Component.hpp"
 #include "gui/Color.hpp"
-#include "lincity/lin-city.h"
 #include "gui/Texture.hpp"
 #include "MapPoint.hpp"
-
+#include "lincity/lintypes.h" //for knowing Construction
 #include <memory>
 
 class XmlReader;
@@ -33,19 +32,19 @@ class CheckButton;
 class MiniMap:public Component
 {
 public:
-    enum DisplayMode {NORMAL,POLLUTION,UB40,STARVE,POWER,FIRE,CRICKET,HEALTH,COAL,TRAFFIC,MAX};
+    enum DisplayMode  {NORMAL,POLLUTION,UB40,STARVE,POWER,FIRE,CRICKET,HEALTH,COAL,TRAFFIC,COMMODITIES,MAX};
 
     MiniMap();
     ~MiniMap();
 
     void parse(XmlReader& reader);
-  
+
     virtual void draw(Painter &painter);
     virtual void event(const Event& event);
-  
-    void setGameViewCorners(const MapPoint& upperLeft,
-            const MapPoint& upperRight, const MapPoint& lowerRight,
-            const MapPoint& lowerLeft);
+
+    void setGameViewCorners(
+        const MapPoint& upperLeft, const MapPoint& lowerRight
+    );
 
     Color getColor(int x,int y) const;
     Color getColorNormal(int x,int y) const;
@@ -53,31 +52,43 @@ public:
     void hideMpsEnv();
 
     void switchView(const std::string& viewname);
+    void scrollPageDown(bool down);
+
+    Commodity getStuffID();
+    void toggleStuffID(int step);
+
+    void mapViewChangeDisplayMode(DisplayMode mode);
 
 private:
     void mapViewButtonClicked(CheckButton* button, int);
     void speedButtonClicked(CheckButton* button, int);
     void zoomInButtonClicked(Button* button);
     void zoomOutButtonClicked(Button* button);
-    
+    void scrollPageDownButtonClicked(Button* button);
+    void scrollPageUpButtonClicked(Button* button);
+
+
     void switchButton(CheckButton* button, int);
     void switchMapViewButton(const std::string &pName);
-    
+
     void attachButtons();
     Component *findRoot(Component *c);
+//FIXME
     Vector2 mapPointToVector(MapPoint p);
-  
-    Vector2 gameViewPoints[ 4 ];
-    short mappointoldtype[WORLD_SIDE_LEN][WORLD_SIDE_LEN];
+
+    void constrainPosition();
+
+    MapPoint upperLeft, lowerRight;
 
     DisplayMode mMode;
-
+    Commodity stuff_ID;
     int tilesize;
     int border;
+    int left, top; //Positioning of minimap
 
     std::vector<CheckButton*> switchButtons;
-    std::auto_ptr<Texture> mTexture;
-    
+    std::unique_ptr<Texture> mTexture;
+
     int mpsXOld, mpsYOld, mpsStyleOld;
 
     bool mFullRefresh;
@@ -90,3 +101,5 @@ private:
 MiniMap* getMiniMap();
 
 #endif
+
+/** @file lincity-ng/MiniMap.hpp */
