@@ -19,6 +19,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <iostream>
 #include <iomanip>
 #include <stdarg.h>
+#include <error.h>
 
 #include <sys/stat.h>
 
@@ -30,7 +31,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "lincity/engglobs.h"
 #include "lincity/lclib.h"
-#include "lincity/fileutil.h"
 
 #include "gui/Component.hpp"
 #include "gui/ComponentLoader.hpp"
@@ -45,110 +45,76 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Dialog.hpp"
 #include "EconomyGraph.hpp"
 
-extern void ok_dial_box(const char *, int, const char *);
-
-
-short mappointoldtype[WORLD_SIDE_LEN][WORLD_SIDE_LEN];
 int selected_module_cost; // this must be changed, when module (or celltype-button) is changed
 
 
-int getMainWindowWidth();
-int getMainWindowHeight();
-
 std::string lastDateText = "";
-int lastMoney = -123456789; 
+int lastMoney = -123456789;
 
 /* This is on in screen_full_refresh, used in *_refresh() */
-char screen_refreshing;
 
 const char* current_month (int current_time);
 void draw_cb_box (int row, int col, int checked);
-
+/*
 int ask_launch_rocket_now (int x, int y)
 {
     new Dialog( ASK_LAUNCH_ROCKET, x, y );
     return 0;
 }
-
-void display_rocket_result_dialog (int result)
-{
-    switch (result) {
-    case ROCKET_LAUNCH_BAD:
-	ok_dial_box ("launch-fail.mes", BAD, 0L);
-	break;
-    case ROCKET_LAUNCH_GOOD:
-	ok_dial_box ("launch-good.mes", GOOD, 0L);
-	break;
-    case ROCKET_LAUNCH_EVAC:
-	ok_dial_box ("launch-evac.mes", GOOD, 0L);
-	break;
-    }
-}
-void draw_background (void);
-void screen_full_refresh (void);
-void init_fonts (void);
+*/
+//void screen_full_refresh (void);
 void initialize_monthgraph (void){
     int i;
     monthgraph_size = getConfig()->monthgraphW;
 
     monthgraph_pop = (int*) malloc (sizeof(int) * monthgraph_size);
     if (monthgraph_pop == 0) {
-	malloc_failure ();
+    error(-1, errno, "malloc");
     }
     monthgraph_starve = (int*) malloc (sizeof(int) * monthgraph_size);
     if (monthgraph_starve == 0) {
-	malloc_failure ();
+    error(-1, errno, "malloc");
     }
     monthgraph_nojobs = (int*) malloc (sizeof(int) * monthgraph_size);
     if (monthgraph_nojobs == 0) {
-	malloc_failure ();
+    error(-1, errno, "malloc");
     }
     monthgraph_ppool = (int*) malloc (sizeof(int) * monthgraph_size);
     if (monthgraph_ppool == 0) {
-	malloc_failure ();
+    error(-1, errno, "malloc");
     }
     for (i = 0; i < monthgraph_size; i++) {
-	monthgraph_pop[i] = 0;
-	monthgraph_starve[i] = 0;
-	monthgraph_nojobs[i] = 0;
-	monthgraph_ppool[i] = 0;
+    monthgraph_pop[i] = 0;
+    monthgraph_starve[i] = 0;
+    monthgraph_nojobs[i] = 0;
+    monthgraph_ppool[i] = 0;
     }
 }
-void rotate_mini_screen (void);
-void advance_mps_style (void);
+//void rotate_mini_screen (void);
+//void advance_mps_style (void);
 /*void update_main_screen (int full_refresh)
 {
 }*/
-void connect_transport_main_screen (void);
+//void connect_transport_main_screen (void);
 
-void refresh_mps (void);
-void advance_monthgraph_style (void);
-void refresh_monthgraph (void);
-void draw_small_yellow_bezel (int x, int y, int h, int w);
-void mini_screen_help (void);
-void status_message(const char *m1, const char* m2);
-void print_time_for_year (void);
-void rotate_main_screen (void);
-void screen_setup (void);
+//void refresh_mps (void);
+//void advance_monthgraph_style (void);
+//void refresh_monthgraph (void);
+//void draw_small_yellow_bezel (int x, int y, int h, int w);
+//void mini_screen_help (void);
+//void print_time_for_year (void);
+//void rotate_main_screen (void);
+//void screen_setup (void);
 
 
 /* Miniscreen */
-void init_mini_map_mouse(void);
-void mini_map_handler(int x, int y, int button);
-void mini_aux_handler(int x, int y, int button);
-/* Message area */
-void display_info_message (int colour, const char* ss, const char* xs)
-{
-    std::ostringstream text;
-    text << "display_info_message: '"<< colour << ss << "' + \"" << xs << "\"\n";
-    updateMessageText( text.str() );
-}
-
-void reset_status_message (void);
+//void init_mini_map_mouse(void);
+//void mini_map_handler(int x, int y, int button);
+//void mini_aux_handler(int x, int y, int button);
 
 /*
  * Display some Text in a Dialog Box with an OK Button.
- * 
+ *
  * see oldgui/screen.cpp: ok_dial_box (char *fn, int good_bad, char *xs)
  *
  * in oldgui good_bad influences the color:
@@ -159,10 +125,10 @@ void reset_status_message (void);
  *
  * fn is the FileName of the message
  *   if good_bad is RESULTS the fn is an absolute filename else
- *   it is a File in message_path.                              
- * 
+ *   it is a File in message_path.
+ *
  * xs is some additional Text, that is shown after the Message
- *    from the File. ( XtraString )  
+ *    from the File. ( XtraString )
  */
 void ok_dial_box (const char *fn, int good_bad, const char *xs)
 {
@@ -177,7 +143,7 @@ void ok_dial_box (const char *fn, int good_bad, const char *xs)
     }
 }
 
-/* 
+/*
  * Update Message in Message Window
  */
 void updateMessageText( const std::string text )
@@ -207,7 +173,7 @@ void updateMessageText( const std::string text )
             desktop->addChildComponent(messageTextComponent);
         }
         Paragraph* messageText = getParagraph(*messageTextComponent, "messageText");
-        
+
         messageText->setText( text );
     } catch(std::exception& e) {
         std::cerr << "Couldn't display message '" << text << "': "
@@ -216,63 +182,80 @@ void updateMessageText( const std::string text )
     }
 }
 
-void updateDate(){
+void updateDate()
+{
     std::ostringstream dateText;
-    
+
     int day = total_time % NUMOF_DAYS_IN_MONTH +1; // 1..NUMOF_DAYS_IN_MONTH
     day = 1 + ( 29 * day / NUMOF_DAYS_IN_MONTH ); // 1..30
-    dateText << day << ". "; 
+    dateText << day << ". ";
 
     dateText << current_month( total_time );
     dateText << " "<< current_year( total_time );
-    
+
     Component* root = getGameView();
     if( !root ) return;
     while( root->getParent() )
         root = root->getParent();
-   
+
     if( dateText.str() == lastDateText ){
         return;
-    } 
+    }
     Component* dateParagraphComponent = 0;
     dateParagraphComponent = root->findComponent( "dateParagraph" );
-    if( dateParagraphComponent == 0 ) {
-        return;
-    }
+    if( dateParagraphComponent == 0 )
+    {   return;}
     Paragraph* dateParagraph = getParagraph( *root, "dateParagraph");
-    if( !dateParagraph ) return;
-    
+    if( !dateParagraph )
+    {   return;}
     dateParagraph->setText( dateText.str() );
     lastDateText = dateText.str();
 }
 
+void string_begadd_number(std::string &str, int number, bool fill) {
+  std::ostringstream result;
+  if (fill) result << std::setw(3) << std::setfill('0');
+  result << number;
+  str = result.str() + std::string(" ") + str;
+};
+
 void updateMoney() {
     if( lastMoney == total_money ){
         return;
     }
     //Prevent overflow
     if (total_money > 2000000000)
-	total_money = 2000000000;
+    total_money = 2000000000;
     else if (total_money < -2000000000)
-	total_money = -2000000000; 
-    
+    total_money = -2000000000;
+
     std::ostringstream moneyText;
+    std::string        postfix ="";
+    std::string        moneystr="";
     int money = total_money;
 
-    if(  abs(money) > 100000000 ){
-       moneyText << money/1000000 << _("MM");  
-    } else {
-        if( abs(money) > 1000000 ){
-            moneyText << money/1000000 << " "; 
-            money %= 1000000;
-            money = abs(money);
-            moneyText << std::setw(6);
-            moneyText << std::setfill('0');
-        }
-        moneyText << money;
+    /*   */if ( abs(money) > 100000000 ) {
+      money/=1000000;
+      postfix=_("M") + std::string(" ");
+    } else if ( abs(money) > 100000    ) {
+      money/=1000;
+      postfix=_("k") + std::string(" ");
     }
-    moneyText << _("$");
-    
+
+    do {
+      int tmpmoney;
+      if (abs(money)<1000) {
+        string_begadd_number(moneystr, money, false);
+        money=0;
+      } else {
+        tmpmoney=abs(money)%1000;
+        money/=1000;
+        string_begadd_number(moneystr, tmpmoney, true);
+      }
+    } while (abs(money)>0);
+
+    moneyText << moneystr << postfix << _("$");
+
     Component* root = getGameView();
     if( !root ) return;
     while( root->getParent() )
@@ -284,7 +267,7 @@ void updateMoney() {
     }
     Paragraph* moneyParagraph = getParagraph( *root, "moneyParagraph");
     if( !moneyParagraph ) return;
-    
+
     moneyParagraph->setText( moneyText.str() );
     lastMoney = total_money;
 }
@@ -296,6 +279,7 @@ void updateMoney() {
  *  showing percent completed, but is also used to update
  *  the current Progressbar.
  */
+
 void prog_box (const char *title, int percent)
 {
     (void) title;
@@ -311,14 +295,12 @@ void print_total_money (void)
 {
     updateMoney();
 }
-
+/*
 void refresh_population_text (void)
 {
-  //  TRACE;
-  update_pbar (PPOP, housed_population + people_pool, 0);
-
+    update_pbar (PPOP, housed_population + people_pool, 0);
 }
-
+*/
 void update_avail_modules (int popup)
 {
     //tell ButtonPanel to check for tech change.
@@ -327,51 +309,53 @@ void update_avail_modules (int popup)
         bp->checkTech( popup );
     }
 }
-
+/*
 void refresh_main_screen()
 {
 }
-
+*/
+/*
 void screen_full_refresh ()
 {
-  updateDate();
-  print_total_money();
-  update_main_screen (true);
+    updateDate();
+    print_total_money();
+    update_main_screen (true);
 }
+*/
 
 void print_stats ()
 {
-  // this show update the financy window or mps
+    // this show update the financy window or mps
+    if (total_time % NUMOF_DAYS_IN_MONTH == (NUMOF_DAYS_IN_MONTH - 1))
+    {
+        mps_refresh();
+        getEconomyGraph()->updateData();
+    }
 
-  if (total_time % NUMOF_DAYS_IN_MONTH == (NUMOF_DAYS_IN_MONTH - 1)) {
-    update_pbars_monthly();
-    mps_refresh();
-    getEconomyGraph()->updateData();
-  }
+    if (total_time % (NUMOF_DAYS_IN_MONTH/5) == NUMOF_DAYS_IN_MONTH / 5 - 1)
+    {   mps_refresh();}
 
-  if (total_time % (NUMOF_DAYS_IN_MONTH/5) == NUMOF_DAYS_IN_MONTH / 5 - 1) {
-    mps_refresh();
-  }
-
-  //check for new tech
-  update_avail_modules (1);
+    //check for new tech
+    update_avail_modules (1);
 
 }
+
+/*
 void update_main_screen_normal (int full_refresh)
 {
     (void) full_refresh;
     return;
-}
-
+}*/
+/*
 void update_main_screen (int full_refresh)
 {
     update_main_screen_normal (full_refresh);
-}
-
+}*/
+/*
 void print_time_for_year ()
 {
-}
-
+}*/
+/*
 int getMainWindowWidth()
 {
   //is only used by old code. 0 is the value that hurts least when the
@@ -382,7 +366,8 @@ int getMainWindowHeight()
 {
   return 0;
 }
-
+*/
+/*
 int yn_dial_box (const char * s1, const char * s2, const char * s3,
         const char *s4)
 {
@@ -395,3 +380,5 @@ int yn_dial_box (const char * s1, const char * s2, const char * s3,
     std::cerr << "-------------------------\n";
     return 0;
 }
+*/
+/** @file lincity-ng/ScreenInterface.cpp */
