@@ -19,5 +19,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __lc_timer_h__
 
 void reset_start_time();
+void get_real_time(void);
+void get_real_time_with(Uint32 sdl_tick);
 
 #endif
+
+/** @file lincity-ng/TimerInterface.hpp */
