@@ -18,14 +18,15 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __MAIN_HPP__
 #define __MAIN_HPP__
 
-#include "tinygettext/TinyGetText.hpp"
+#include "tinygettext/tinygettext.hpp"
 
 enum MainState {
     MAINMENU, INGAME, QUIT, RESTART
 };
 
-void initVideo(int width, int height);
-void flipScreenBuffer();
+
+void videoSizeChanged(int width, int height);
+void resizeVideo(int width, int height, bool fullscreen);
 
 class Painter;
 
@@ -37,3 +38,6 @@ extern Painter* painter;
 
 #endif
 
+
+/** @file lincity-ng/main.hpp */
+
