@@ -1,5 +1,6 @@
 #include "lc_locale.h"
 #include <stdlib.h>
+#include <stdio.h>
 
 void lincity_set_locale(void)
 {
@@ -16,20 +17,22 @@ void lincity_set_locale(void)
     /* Some special stoopid way of setting locale for microsoft gettext */
     language = getenv("LANGUAGE");
     if (language) {
-        debug_printf("Environment variable LANGUAGE is %s\n", language);
+        fprintf(stderr, "Environment variable LANGUAGE is %s\n", language);
         snprintf(language_buf, MAX_LANG_BUF, "LANGUAGE=%s", language);
         gettext_putenv(language_buf);
     } else {
-        debug_printf("Environment variable LANGUAGE not set.\n");
+        fprintf(stderr, "Environment variable LANGUAGE not set.\n");
     }
 #else
     locale = setlocale(LC_ALL, "");
-    debug_printf("Setting entire locale to %s\n", locale);
+    fprintf(stderr, "Setting entire locale to %s\n", locale);
     locale = setlocale(LC_MESSAGES, "");
-    debug_printf("Setting messages locale to %s\n", locale);
+    fprintf(stderr, "Setting messages locale to %s\n", locale);
     localem = setlocale(LC_MESSAGES, NULL);
-    debug_printf("Query locale is %s\n", localem);
+    fprintf(stderr, "Query locale is %s\n", localem);
 #endif
 #endif /* ENABLE_NLS */
     return;
 }
+
+/** @file lincity/lc_locale.cpp */
