@@ -7,11 +7,13 @@
 #define __simulate_h__
 
 void do_time_step(void);
-int count_groups(int gr);
-void count_all_groups(int *group_count);
-void set_mappoint(int x, int y, short selected_type);
-void do_rand_ecology(int x, int y);
+void do_animate(void);
+//int count_groups(int gr);
+//void count_all_groups(int *group_count);
+//void set_mappoint(int x, int y, short selected_type);
 
 extern void connect_rivers(void);
 
 #endif /* __simulate_h__ */
+
+/** @file lincity/simulate.h */
