@@ -4,27 +4,23 @@
  * Lincity is copyright (c) I J Peters 1995-1997, (c) Greg Sharp 1997-2002.
  * Portions copyright (c) Corey Keasling, 2000-2002.
  * ---------------------------------------------------------------------- */
-#include "lcconfig.h"
-#include <stdio.h>
-#include <stdlib.h>
-
-#include "lin-city.h"
 #include "engglobs.h"
-#include "gui_interface/pbar_interface.h"
 #include "stats.h"
+#include "modules/market.h" //for inventory_market
 
 /* ---------------------------------------------------------------------- *
  * Public Global Variables
  * ---------------------------------------------------------------------- */
 
 /* Daily accumulators */
-int food_in_markets;
-int jobs_in_markets;
-int coal_in_markets;
-int goods_in_markets;
-int ore_in_markets;
-int steel_in_markets;
-int waste_in_markets;
+//int food_in_markets;
+//int jobs_in_markets;
+//int coal_in_markets;
+//int goods_in_markets;
+//int ore_in_markets;
+//int steel_in_markets;
+//int waste_in_markets;
+int dbirths, ddeaths;
 
 /* Monthly accumulators */
 int tfood_in_markets;
@@ -35,8 +31,14 @@ int tore_in_markets;
 int tsteel_in_markets;
 int twaste_in_markets;
 int tpopulation;
+int thousing;
 int tstarving_population;
 int tunemployed_population;
+int tbirths, tdeaths, tunnat_deaths;
+int ltbirths = 0;
+int ltdeaths = 0;
+int ltunnat_deaths = 0;
+std::deque<int> birthq, deathq, unnatdeathq;
 
 /* yearly */
 int income_tax;
@@ -76,44 +78,87 @@ int ly_interest;
 int ly_windmill_cost;
 int ly_cricket_cost;
 int ly_fire_cost;
+int ly_births = 0;
+int ly_deaths = 0;
+int ly_unnatdeaths = 0;
 
 /* Averaging variables */
 int data_last_month;
 
-/* ---------------------------------------------------------------------- *
- * Private Function Prototypes
- * ---------------------------------------------------------------------- */
-void inventory_market(int x, int y);
 
 void init_daily(void)
 {
     population = 0;
+    housing = 0;
     starving_population = 0;
     unemployed_population = 0;
-    food_in_markets = 0;
-    jobs_in_markets = 0;
-    coal_in_markets = 0;
-    goods_in_markets = 0;
-    ore_in_markets = 0;
-    steel_in_markets = 0;
-    waste_in_markets = 0;
+    ddeaths = 0;
+    dbirths = 0;
 }
 
 void init_monthly(void)
 {
     data_last_month = 0;
-
     tpopulation = 0;
+    thousing = 0;
     tstarving_population = 0;
-    tfood_in_markets = 0;
-    tjobs_in_markets = 0;
-    tcoal_in_markets = 0;
-    tgoods_in_markets = 0;
-    tore_in_markets = 0;
-    tsteel_in_markets = 0;
-    twaste_in_markets = 0;
     tunemployed_population = 0;
-    unnat_deaths = 0;
+    init_census();
+    birthq.push_back(tbirths);
+    deathq.push_back(tdeaths);
+    unnatdeathq.push_back(tunnat_deaths);
+    ly_births += tbirths;
+    ly_deaths += tdeaths;
+    ly_unnatdeaths += tunnat_deaths;
+    int s = birthq.size();
+    if(s>12)
+    {
+        ly_births -= birthq.front();
+        ly_deaths -= deathq.front();
+        ly_unnatdeaths -= unnatdeathq.front();
+        --s;
+        birthq.pop_front();
+        deathq.pop_front();
+        unnatdeathq.pop_front();
+        ltbirths = ly_births;
+        ltdeaths = ly_deaths;
+        ltunnat_deaths = ly_unnatdeaths;
+    }
+    else
+    {
+        ltbirths = 12*ly_births/s;
+        ltdeaths = 12*ly_deaths/s;
+        ltunnat_deaths = 12*ly_unnatdeaths/s;
+    }
+
+    tbirths = 0;
+    tdeaths = 0;
+    tunnat_deaths = 0;
+}
+
+void init_census()
+{
+    tstat_census[STUFF_FOOD] = 0;
+    tstat_census[STUFF_JOBS] = 0;
+    tstat_census[STUFF_COAL] = 0;
+    tstat_census[STUFF_ORE] = 0;
+    tstat_census[STUFF_WATER] = 0;
+    tstat_census[STUFF_GOODS] = 0;
+    tstat_census[STUFF_WASTE] = 0;
+    tstat_census[STUFF_STEEL] = 0;
+    tstat_census[STUFF_KWH] = 0;
+    tstat_census[STUFF_MWH] = 0;
+
+    tstat_capacities[STUFF_FOOD] = 1;
+    tstat_capacities[STUFF_JOBS] = 1;
+    tstat_capacities[STUFF_COAL] = 1;
+    tstat_capacities[STUFF_ORE] = 1;
+    tstat_capacities[STUFF_STEEL] = 1;
+    tstat_capacities[STUFF_WATER] = 1;
+    tstat_capacities[STUFF_GOODS] = 1;
+    tstat_capacities[STUFF_WASTE] = 1;
+    tstat_capacities[STUFF_KWH] = 1;
+    tstat_capacities[STUFF_MWH] = 1;
 }
 
 void init_yearly(void)
@@ -158,57 +203,26 @@ void init_lastyear(void)
     ly_fire_cost = 0;
 }
 
-void inventory(int x, int y)
-{
-
-    switch (get_group_of_type(MP_TYPE(x, y))) {
-
-    case GROUP_MARKET:
-        inventory_market(x, y);
-        break;
-
-    default:{
-            printf("Default in inventory(%d,%d): got %d\n", x, y, get_group_of_type(MP_TYPE(x, y)));
-            break;
-        }
-
-    }
-}
-
 void init_inventory(void)
 {
+    init_census();
     init_daily();
     init_monthly();
     init_yearly();
     init_lastyear();
 }
 
-void inventory_market(int x, int y)
-{
-    food_in_markets += MP_INFO(x, y).int_1;
-    jobs_in_markets += MP_INFO(x, y).int_2;
-    coal_in_markets += MP_INFO(x, y).int_3;
-    goods_in_markets += MP_INFO(x, y).int_4;
-    ore_in_markets += MP_INFO(x, y).int_5;
-    steel_in_markets += MP_INFO(x, y).int_6;
-    waste_in_markets += MP_INFO(x, y).int_7;
-}
-
-/* XXX: WCK:  Why oh why must we divide by arbitrary values, below? */
-/* If this is fixed, make sure to fix it in pbar also! */
-
 void add_daily_to_monthly(void)
 {
-    data_last_month++;
+    ++data_last_month;
 
     tpopulation += population;
+    thousing += housing;
     tstarving_population += starving_population;
-    tfood_in_markets += food_in_markets / 1000;
-    tjobs_in_markets += jobs_in_markets / 1000;
-    tcoal_in_markets += coal_in_markets / 250;
-    tgoods_in_markets += goods_in_markets / 500;
-    tore_in_markets += ore_in_markets / 500;
-    tsteel_in_markets += steel_in_markets / 25;
-    twaste_in_markets += waste_in_markets;
     tunemployed_population += unemployed_population;
+    tbirths += dbirths;
+    tdeaths += ddeaths;
 }
+
+/** @file lincity/stats.cpp */
+
