@@ -33,6 +33,8 @@ from the Author.
 #include <ctype.h>
 
 #ifdef WIN32
+#define NOMINMAX
+#define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <winnt.h>
 #endif
@@ -182,7 +184,7 @@ canonise_fl(FL_Locale *l) {
 #define RML(pn,sn) MAKELANGID(LANG_##pn, SUBLANG_##sn)
 typedef struct {
   LANGID id;
-  char*  code;
+  const char*  code;
 } IDToCode;
 static const IDToCode both_to_code[] = {
   {ML(ENGLISH,US),           "en_US.ISO_8859-1"},
@@ -551,3 +553,6 @@ FL_FreeLocale(FL_Locale **locale) {
     }
   }
 }
+
+/** @file tinygettext/findlocale.cpp */
+
